@@ -10,6 +10,7 @@
 #include <schroedinger/schroarith.h>
 #include <schroedinger/schrotables.h>
 #include <schroedinger/schrodebug.h>
+#include <orc/orc.h>
 
 static const unsigned int next_list[] = {
   0,
@@ -120,29 +121,99 @@ static const uint16_t lut[256] = {
    805,  750,  690,  625,  553,  471,  376,  255
 };
 
+/* This is a copy of the above lookup-table, with the
+   elements interleaved in a way that decreases the number
+   of operations during decode. */
+static const int16_t lut_interleaved[512] = {
+    255,     0,   376,    -2,   471,    -5,   553,    -8,
+    625,   -11,   690,   -15,   750,   -20,   805,   -24,
+    857,   -29,   906,   -35,   952,   -41,   995,   -47,
+   1037,   -53,  1077,   -60,  1114,   -67,  1151,   -74,
+   1186,   -82,  1219,   -89,  1251,   -97,  1282,  -106,
+   1312,  -114,  1341,  -123,  1369,  -132,  1396,  -141,
+   1422,  -150,  1447,  -160,  1471,  -170,  1495,  -180,
+   1518,  -190,  1540,  -201,  1561,  -211,  1582,  -222,
+   1602,  -233,  1622,  -244,  1640,  -256,  1659,  -267,
+   1676,  -279,  1694,  -291,  1710,  -303,  1727,  -315,
+   1742,  -327,  1757,  -340,  1772,  -353,  1786,  -366,
+   1800,  -379,  1814,  -392,  1827,  -405,  1839,  -419,
+   1851,  -433,  1863,  -447,  1874,  -461,  1885,  -475,
+   1896,  -489,  1906,  -504,  1916,  -518,  1925,  -533,
+   1934,  -548,  1943,  -563,  1952,  -578,  1960,  -593,
+   1968,  -609,  1975,  -624,  1982,  -640,  1989,  -656,
+   1996,  -672,  2002,  -688,  2008,  -705,  2013,  -721,
+   2019,  -738,  2024,  -754,  2029,  -771,  2033,  -788,
+   2038,  -805,  2042,  -822,  2045,  -840,  2049,  -857,
+   2052,  -875,  2055,  -892,  2058,  -910,  2060,  -928,
+   2063,  -946,  2065,  -964,  2066,  -983,  2068, -1001,
+   2069, -1020,  2070, -1038,  2071, -1057,  2072, -1076,
+   2072, -1095,  2072, -1114,  2072, -1133,  2072, -1153,
+   2072, -1172,  2071, -1192,  2070, -1211,  2069, -1231,
+   2068, -1251,  2066, -1271,  2065, -1291,  2063, -1311,
+   2061, -1332,  2058, -1352,  2056, -1373,  2053, -1393,
+   2050, -1414,  2047, -1435,  2044, -1456,  2040, -1477,
+   2037, -1498,  2033, -1520,  2029, -1541,  2025, -1562,
+   2021, -1584,  2016, -1606,  2011, -1628,  2006, -1649,
+   2001, -1671,  1996, -1694,  1991, -1716,  1985, -1738,
+   1980, -1760,  1974, -1783,  1968, -1806,  1961, -1828,
+   1955, -1851,  1949, -1874,  1942, -1897,  1935, -1920,
+   1920, -1935,  1897, -1942,  1874, -1949,  1851, -1955,
+   1828, -1961,  1806, -1968,  1783, -1974,  1760, -1980,
+   1738, -1985,  1716, -1991,  1694, -1996,  1671, -2001,
+   1649, -2006,  1628, -2011,  1606, -2016,  1584, -2021,
+   1562, -2025,  1541, -2029,  1520, -2033,  1498, -2037,
+   1477, -2040,  1456, -2044,  1435, -2047,  1414, -2050,
+   1393, -2053,  1373, -2056,  1352, -2058,  1332, -2061,
+   1311, -2063,  1291, -2065,  1271, -2066,  1251, -2068,
+   1231, -2069,  1211, -2070,  1192, -2071,  1172, -2072,
+   1153, -2072,  1133, -2072,  1114, -2072,  1095, -2072,
+   1076, -2072,  1057, -2071,  1038, -2070,  1020, -2069,
+   1001, -2068,   983, -2066,   964, -2065,   946, -2063,
+    928, -2060,   910, -2058,   892, -2055,   875, -2052,
+    857, -2049,   840, -2045,   822, -2042,   805, -2038,
+    788, -2033,   771, -2029,   754, -2024,   738, -2019,
+    721, -2013,   705, -2008,   688, -2002,   672, -1996,
+    656, -1989,   640, -1982,   624, -1975,   609, -1968,
+    593, -1960,   578, -1952,   563, -1943,   548, -1934,
+    533, -1925,   518, -1916,   504, -1906,   489, -1896,
+    475, -1885,   461, -1874,   447, -1863,   433, -1851,
+    419, -1839,   405, -1827,   392, -1814,   379, -1800,
+    366, -1786,   353, -1772,   340, -1757,   327, -1742,
+    315, -1727,   303, -1710,   291, -1694,   279, -1676,
+    267, -1659,   256, -1640,   244, -1622,   233, -1602,
+    222, -1582,   211, -1561,   201, -1540,   190, -1518,
+    180, -1495,   170, -1471,   160, -1447,   150, -1422,
+    141, -1396,   132, -1369,   123, -1341,   114, -1312,
+    106, -1282,    97, -1251,    89, -1219,    82, -1186,
+     74, -1151,    67, -1114,    60, -1077,    53, -1037,
+     47,  -995,    41,  -952,    35,  -906,    29,  -857,
+     24,  -805,    20,  -750,    15,  -690,    11,  -625,
+      8,  -553,     5,  -471,     2,  -376,     0,  -255
+};
+
 SchroArith *
 schro_arith_new (void)
 {
   SchroArith *arith;
 
-  arith = schro_malloc0 (sizeof(*arith));
+  arith = schro_malloc (sizeof (*arith));
 
   return arith;
 }
 
 void
-schro_arith_free (SchroArith *arith)
+schro_arith_free (SchroArith * arith)
 {
-  schro_free(arith);
+  schro_free (arith);
 }
 
 void
-schro_arith_decode_init (SchroArith *arith, SchroBuffer *buffer)
+schro_arith_decode_init (SchroArith * arith, SchroBuffer * buffer)
 {
   int i;
   int size;
 
-  memset(arith, 0, sizeof(SchroArith));
+  orc_memset (arith, 0, sizeof (SchroArith));
   arith->range[0] = 0;
   arith->range[1] = 0xffff0000;
   arith->range_size = arith->range[1] - arith->range[0];
@@ -159,23 +230,20 @@ schro_arith_decode_init (SchroArith *arith, SchroBuffer *buffer)
   arith->code |= ((size > 3) ? arith->dataptr[3] : 0xff);
   arith->offset = 3;
 
-  for(i=0;i<SCHRO_CTX_LAST;i++){
+  for (i = 0; i < SCHRO_CTX_LAST; i++) {
     arith->contexts[i].next = next_list[i];
     arith->probabilities[i] = 0x8000;
   }
 
-  for(i=0;i<256;i++){
-    arith->lut[2*i] = lut[255-i];
-    arith->lut[2*i+1] = -lut[i];
-  }
+  orc_memcpy (arith->lut, (void *) lut_interleaved, 512 * sizeof (int16_t));
 }
 
 void
-schro_arith_encode_init (SchroArith *arith, SchroBuffer *buffer)
+schro_arith_encode_init (SchroArith * arith, SchroBuffer * buffer)
 {
   int i;
 
-  memset(arith, 0, sizeof(SchroArith));
+  orc_memset (arith, 0, sizeof (SchroArith));
   arith->range[0] = 0;
   arith->range[1] = 0xffff;
   arith->range_size = arith->range[1] - arith->range[0];
@@ -185,25 +253,25 @@ schro_arith_encode_init (SchroArith *arith, SchroBuffer *buffer)
   arith->offset = 0;
   arith->dataptr = arith->buffer->data;
 
-  for(i=0;i<SCHRO_CTX_LAST;i++){
+  for (i = 0; i < SCHRO_CTX_LAST; i++) {
     arith->contexts[i].next = next_list[i];
     arith->probabilities[i] = 0x8000;
   }
 
-  for(i=0;i<256;i++){
+  for (i = 0; i < 256; i++) {
     arith->lut[i] = lut[i];
-    arith->lut[511-i] = lut[255-i];
+    arith->lut[511 - i] = lut[255 - i];
   }
 }
 
 #ifdef unused
 void
-schro_arith_estimate_init (SchroArith *arith)
+schro_arith_estimate_init (SchroArith * arith)
 {
   int i;
 
-  memset(arith, 0, sizeof(SchroArith));
-  for(i=0;i<SCHRO_CTX_LAST;i++){
+  memset (arith, 0, sizeof (SchroArith));
+  for (i = 0; i < SCHRO_CTX_LAST; i++) {
     arith->contexts[i].stat_range = 0xffff;
     arith->contexts[i].next = next_list[i];
     arith->probabilities[i] = 0x8000;
@@ -212,7 +280,7 @@ schro_arith_estimate_init (SchroArith *arith)
 #endif
 
 void
-schro_arith_decode_flush (SchroArith *arith)
+schro_arith_decode_flush (SchroArith * arith)
 {
   if (arith->cntr < 8) {
     arith->offset++;
@@ -220,7 +288,7 @@ schro_arith_decode_flush (SchroArith *arith)
 }
 
 void
-schro_arith_flush (SchroArith *arith)
+schro_arith_flush (SchroArith * arith)
 {
   int extra_byte;
   int i;
@@ -231,10 +299,11 @@ schro_arith_flush (SchroArith *arith)
     extra_byte = FALSE;
   }
 
-for(i=0;i<16;i++){
-  if ((arith->range[0] | ((1<<(i+1))-1)) > arith->range[1] - 1) break;
-}
-arith->range[0] |= ((1<<i)-1);
+  for (i = 0; i < 16; i++) {
+    if ((arith->range[0] | ((1 << (i + 1)) - 1)) > arith->range[1] - 1)
+      break;
+  }
+  arith->range[0] |= ((1 << i) - 1);
 //arith->range[0] += arith->range[1] - 1;
 
   while (arith->cntr < 8) {
@@ -243,8 +312,8 @@ arith->range[0] |= ((1<<i)-1);
     arith->cntr++;
   }
 
-  if (arith->range[0] >= (1<<24)) {
-    arith->dataptr[arith->offset-1]++;
+  if (arith->range[0] >= (1 << 24)) {
+    arith->dataptr[arith->offset - 1]++;
     while (arith->carry) {
       arith->dataptr[arith->offset] = 0x00;
       arith->carry--;
@@ -266,7 +335,7 @@ arith->range[0] |= ((1<<i)-1);
     arith->dataptr[arith->offset] = arith->range[0] >> 0;
     arith->offset++;
   }
-  while (arith->offset > 1 && arith->dataptr[arith->offset-1] == 0xff) {
+  while (arith->offset > 1 && arith->dataptr[arith->offset - 1] == 0xff) {
     arith->offset--;
   }
 }
@@ -276,17 +345,17 @@ arith->range[0] |= ((1<<i)-1);
 #define faster
 #ifdef faster
 static int
-__schro_arith_decode_bit (SchroArith *arith, unsigned int i)
+__schro_arith_decode_bit (SchroArith * arith, unsigned int i)
 {
   unsigned int range_x_prob;
   int value;
   int lut_index;
 
   range_x_prob = (arith->range[1] * arith->probabilities[i]) >> 16;
-  lut_index = arith->probabilities[i]>>8;
+  lut_index = arith->probabilities[i] >> 8;
 
   value = (arith->code - arith->range[0] >= range_x_prob);
-  arith->probabilities[i] += arith->lut[(value<<8) | lut_index];
+  arith->probabilities[i] += arith->lut[(value << 8) | lut_index];
   if (value) {
     arith->range[0] += range_x_prob;
     arith->range[1] -= range_x_prob;
@@ -299,7 +368,7 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
     arith->range[1] <<= 1;
 
     arith->code <<= 1;
-    arith->code |= arith->shift >> (7-arith->cntr)&1;
+    arith->code |= arith->shift >> (7 - arith->cntr) & 1;
 
     if (!--arith->cntr) {
       arith->offset++;
@@ -312,7 +381,7 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
       arith->code &= 0xffff;
 
       if (arith->code < arith->range[0]) {
-        arith->code |= (1<<16);
+        arith->code |= (1 << 16);
       }
       arith->cntr = 8;
     }
@@ -322,7 +391,7 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
 }
 #else
 static int
-__schro_arith_decode_bit (SchroArith *arith, unsigned int i)
+__schro_arith_decode_bit (SchroArith * arith, unsigned int i)
 {
   unsigned int range;
   unsigned int probability0;
@@ -339,10 +408,10 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
   if (value) {
     arith->range[0] = arith->range[0] + range_x_prob;
     arith->range[1] -= range_x_prob;
-    arith->probabilities[i] -= lut[arith->probabilities[i]>>8];
+    arith->probabilities[i] -= lut[arith->probabilities[i] >> 8];
   } else {
     arith->range[1] = range_x_prob;
-    arith->probabilities[i] += lut[255-(arith->probabilities[i]>>8)];
+    arith->probabilities[i] += lut[255 - (arith->probabilities[i] >> 8)];
   }
 
   while (arith->range[1] <= 0x4000) {
@@ -350,7 +419,7 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
     arith->range[1] <<= 1;
 
     arith->code <<= 1;
-    arith->code |= (arith->dataptr[arith->offset] >> (7-arith->cntr))&1;
+    arith->code |= (arith->dataptr[arith->offset] >> (7 - arith->cntr)) & 1;
 
     if (!--arith->cntr) {
       arith->offset++;
@@ -358,7 +427,7 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
       arith->code &= 0xffff;
 
       if (arith->code < arith->range[0]) {
-        arith->code |= (1<<16);
+        arith->code |= (1 << 16);
       }
       arith->cntr = 8;
     }
@@ -368,7 +437,7 @@ __schro_arith_decode_bit (SchroArith *arith, unsigned int i)
 }
 #endif
 int
-_schro_arith_decode_bit (SchroArith *arith, unsigned int i)
+_schro_arith_decode_bit (SchroArith * arith, unsigned int i)
 {
   return __schro_arith_decode_bit (arith, i);
 }
@@ -376,7 +445,7 @@ _schro_arith_decode_bit (SchroArith *arith, unsigned int i)
 
 #ifndef SCHRO_ARITH_DEFINE_INLINE
 void
-_schro_arith_encode_bit (SchroArith *arith, int i, int value)
+_schro_arith_encode_bit (SchroArith * arith, int i, int value)
 {
   unsigned int range;
   unsigned int probability0;
@@ -389,10 +458,10 @@ _schro_arith_encode_bit (SchroArith *arith, int i, int value)
   if (value) {
     arith->range[0] = arith->range[0] + range_x_prob;
     arith->range[1] -= range_x_prob;
-    arith->probabilities[i] -= lut[arith->probabilities[i]>>8];
+    arith->probabilities[i] -= lut[arith->probabilities[i] >> 8];
   } else {
     arith->range[1] = range_x_prob;
-    arith->probabilities[i] += lut[255-(arith->probabilities[i]>>8)];
+    arith->probabilities[i] += lut[255 - (arith->probabilities[i] >> 8)];
   }
 
   while (arith->range[1] <= 0x4000) {
@@ -401,12 +470,12 @@ _schro_arith_encode_bit (SchroArith *arith, int i, int value)
     arith->cntr++;
 
     if (arith->cntr == 8) {
-      if (arith->range[0] < (1<<24) &&
-          (arith->range[0] + arith->range[1]) >= (1<<24)) {
+      if (arith->range[0] < (1 << 24) &&
+          (arith->range[0] + arith->range[1]) >= (1 << 24)) {
         arith->carry++;
       } else {
-        if (arith->range[0] >= (1<<24)) {
-          arith->dataptr[arith->offset-1]++;
+        if (arith->range[0] >= (1 << 24)) {
+          arith->dataptr[arith->offset - 1]++;
           while (arith->carry) {
             arith->dataptr[arith->offset] = 0x00;
             arith->carry--;
@@ -432,7 +501,7 @@ _schro_arith_encode_bit (SchroArith *arith, int i, int value)
 
 #ifdef unused
 void
-schro_arith_estimate_bit (SchroArith *arith, int i, int value)
+schro_arith_estimate_bit (SchroArith * arith, int i, int value)
 {
   unsigned int range;
   unsigned int probability0;
@@ -444,11 +513,11 @@ schro_arith_estimate_bit (SchroArith *arith, int i, int value)
 
   if (value) {
     arith->contexts[i].stat_range -= range_x_prob;
-    arith->probabilities[i] -= lut[arith->probabilities[i]>>8];
+    arith->probabilities[i] -= lut[arith->probabilities[i] >> 8];
     arith->contexts[i].ones++;
   } else {
     arith->contexts[i].stat_range = range_x_prob;
-    arith->probabilities[i] += lut[255-(arith->probabilities[i]>>8)];
+    arith->probabilities[i] += lut[255 - (arith->probabilities[i] >> 8)];
   }
   arith->contexts[i].n_symbols++;
 
@@ -464,32 +533,32 @@ static int
 maxbit (unsigned int x)
 {
   int i;
-  for(i=0;x;i++){
+  for (i = 0; x; i++) {
     x >>= 1;
   }
   return i;
 }
 
 void
-_schro_arith_encode_uint (SchroArith *arith, int cont_context,
+_schro_arith_encode_uint (SchroArith * arith, int cont_context,
     int value_context, int value)
 {
   int i;
   int n_bits;
 
   value++;
-  n_bits = maxbit(value);
-  for(i=0;i<n_bits - 1;i++){
+  n_bits = maxbit (value);
+  for (i = 0; i < n_bits - 1; i++) {
     _schro_arith_encode_bit (arith, cont_context, 0);
     _schro_arith_encode_bit (arith, value_context,
-        (value>>(n_bits - 2 - i))&1);
+        (value >> (n_bits - 2 - i)) & 1);
     cont_context = arith->contexts[cont_context].next;
   }
   _schro_arith_encode_bit (arith, cont_context, 1);
 }
 
 void
-_schro_arith_encode_sint (SchroArith *arith, int cont_context,
+_schro_arith_encode_sint (SchroArith * arith, int cont_context,
     int value_context, int sign_context, int value)
 {
   int sign;
@@ -509,18 +578,18 @@ _schro_arith_encode_sint (SchroArith *arith, int cont_context,
 
 #ifdef unused
 void
-schro_arith_estimate_uint (SchroArith *arith, int cont_context,
+schro_arith_estimate_uint (SchroArith * arith, int cont_context,
     int value_context, int value)
 {
   int i;
   int n_bits;
 
   value++;
-  n_bits = maxbit(value);
-  for(i=0;i<n_bits - 1;i++){
+  n_bits = maxbit (value);
+  for (i = 0; i < n_bits - 1; i++) {
     schro_arith_estimate_bit (arith, cont_context, 0);
     schro_arith_estimate_bit (arith, value_context,
-        (value>>(n_bits - 2 - i))&1);
+        (value >> (n_bits - 2 - i)) & 1);
     cont_context = arith->contexts[cont_context].next;
   }
   schro_arith_estimate_bit (arith, cont_context, 1);
@@ -529,7 +598,7 @@ schro_arith_estimate_uint (SchroArith *arith, int cont_context,
 
 #ifdef unused
 void
-schro_arith_estimate_sint (SchroArith *arith, int cont_context,
+schro_arith_estimate_sint (SchroArith * arith, int cont_context,
     int value_context, int sign_context, int value)
 {
   int sign;
@@ -549,41 +618,43 @@ schro_arith_estimate_sint (SchroArith *arith, int cont_context,
 
 #ifndef SCHRO_ARITH_DEFINE_INLINE
 int
-_schro_arith_decode_uint (SchroArith *arith, unsigned int cont_context,
+_schro_arith_decode_uint (SchroArith * arith, unsigned int cont_context,
     unsigned int value_context)
 {
-  unsigned int bits=1;
-  int count=0;
+  unsigned int bits = 1;
+  int count = 0;
 
-  while(!__schro_arith_decode_bit (arith, cont_context)) {
+  while (!__schro_arith_decode_bit (arith, cont_context)) {
     bits <<= 1;
     bits |= __schro_arith_decode_bit (arith, value_context);
     cont_context = arith->contexts[cont_context].next;
     count++;
 
     /* FIXME being careful */
-    if (count == 30) break;
+    if (count == 30)
+      break;
   }
   return bits - 1;
 }
 #endif
 
 int
-_schro_arith_decode_sint (SchroArith *arith, unsigned int cont_context,
+_schro_arith_decode_sint (SchroArith * arith, unsigned int cont_context,
     unsigned int value_context, unsigned int sign_context)
 {
-  unsigned int bits=1;
-  int count=0;
+  unsigned int bits = 1;
+  int count = 0;
   int value;
 
-  while(!_schro_arith_decode_bit (arith, cont_context)) {
+  while (!_schro_arith_decode_bit (arith, cont_context)) {
     bits <<= 1;
     bits |= _schro_arith_decode_bit (arith, value_context);
     cont_context = arith->contexts[cont_context].next;
     count++;
 
     /* FIXME being careful */
-    if (count == 30) break;
+    if (count == 30)
+      break;
   }
   value = bits - 1;
 
@@ -599,20 +670,20 @@ _schro_arith_decode_sint (SchroArith *arith, unsigned int cont_context,
 /* wrappers */
 
 void
-schro_arith_encode_bit (SchroArith *arith, int i, int value)
+schro_arith_encode_bit (SchroArith * arith, int i, int value)
 {
   _schro_arith_encode_bit (arith, i, value);
 }
 
 void
-schro_arith_encode_uint (SchroArith *arith, int cont_context,
+schro_arith_encode_uint (SchroArith * arith, int cont_context,
     int value_context, int value)
 {
   _schro_arith_encode_uint (arith, cont_context, value_context, value);
 }
 
 void
-schro_arith_encode_sint (SchroArith *arith, int cont_context,
+schro_arith_encode_sint (SchroArith * arith, int cont_context,
     int value_context, int sign_context, int value)
 {
   _schro_arith_encode_sint (arith, cont_context, value_context,
@@ -620,23 +691,22 @@ schro_arith_encode_sint (SchroArith *arith, int cont_context,
 }
 
 int
-schro_arith_decode_bit (SchroArith *arith, unsigned int context)
+schro_arith_decode_bit (SchroArith * arith, unsigned int context)
 {
   return _schro_arith_decode_bit (arith, context);
 }
 
 int
-schro_arith_decode_uint (SchroArith *arith, unsigned int cont_context,
+schro_arith_decode_uint (SchroArith * arith, unsigned int cont_context,
     unsigned int value_context)
 {
   return _schro_arith_decode_uint (arith, cont_context, value_context);
 }
 
 int
-schro_arith_decode_sint (SchroArith *arith, unsigned int cont_context,
+schro_arith_decode_sint (SchroArith * arith, unsigned int cont_context,
     unsigned int value_context, unsigned int sign_context)
 {
   return _schro_arith_decode_sint (arith, cont_context,
       value_context, sign_context);
 }
-
