@@ -7,12 +7,13 @@
 SCHRO_BEGIN_DECLS
 
 typedef struct _SchroBuffer SchroBuffer;
+typedef struct _SchroTag SchroTag;
 
 struct _SchroBuffer
 {
   /*< private >*/
   unsigned char *data;
-  int length;
+  unsigned int length;
 
   int ref_count;
 
@@ -20,6 +21,14 @@ struct _SchroBuffer
 
   void (*free) (SchroBuffer *, void *);
   void *priv;
+
+  SchroTag* tag;
+};
+
+struct _SchroTag
+{
+  void (*free) (void *);
+  void *value;
 };
 
 SchroBuffer *schro_buffer_new (void);
@@ -30,7 +39,9 @@ SchroBuffer *schro_buffer_new_subbuffer (SchroBuffer * buffer, int offset,
 SchroBuffer *schro_buffer_dup (SchroBuffer * buffer);
 SchroBuffer * schro_buffer_ref (SchroBuffer * buffer);
 void schro_buffer_unref (SchroBuffer * buffer);
-int schro_buffer_compare_data (SchroBuffer *a, SchroBuffer *b);
+
+SchroTag *schro_tag_new (void *value, void (*free_func) (void *));
+void schro_tag_free (SchroTag *tag);
 
 SCHRO_END_DECLS
 
