@@ -2,6 +2,10 @@
 #ifndef __SCHRO_CUDA_H__
 #define __SCHRO_CUDA_H__
 
+SCHRO_BEGIN_DECLS
+
+#ifdef SCHRO_ENABLE_UNSTABLE_API
+
 void schro_cuda_init (void);
 SchroMemoryDomain *schro_memory_domain_new_cuda (void);
 
@@ -13,3 +17,7 @@ void schro_frame_inverse_iwt_transform_cuda (SchroFrame *frame,
 
 #endif
 
+SCHRO_END_DECLS
+
+#endif
+
