@@ -536,9 +536,10 @@ schro_frame_set_wavelet_params (SchroEncoderFrame * frame)
 
   /* overrides for near-lossless */
   if (encoder->rate_control == 0) {
-    if (encoder->noise_threshold < 40.0) {
+    double offset = 6.0 * (encoder->bit_depth - 8);
+    if (encoder->noise_threshold < 40.0 + offset) {
       /* do nothing */
-    } else if (encoder->noise_threshold < 47.0) {
+    } else if (encoder->noise_threshold < 47.0 + offset) {
       params->wavelet_filter_index = 1;
     } else {
       params->wavelet_filter_index = 3;
@@ -687,7 +688,7 @@ schro_encoder_handle_gop_tworef (SchroEncoder * encoder, int i)
   SchroEncoderFrame *f;
   int j;
   int gop_length;
-  double scs_sum;
+  //double scs_sum;
 
   frame = encoder->frame_queue->elements[i].data;
 
@@ -707,7 +708,7 @@ schro_encoder_handle_gop_tworef (SchroEncoder * encoder, int i)
     gop_length = MIN (gop_length, encoder->frame_queue->n - i);
   }
   //intra_start = frame->start_sequence_header;
-  scs_sum = 0;
+  //scs_sum = 0;
   for (j = 0; j < gop_length; j++) {
     if (i + j >= encoder->frame_queue->n) {
       SCHRO_DEBUG ("not enough pictures in queue");
