@@ -54,20 +54,19 @@ SchroFrame *
 schro_frame_new_and_alloc (SchroMemoryDomain * domain, SchroFrameFormat format,
     int width, int height)
 {
-  return schro_frame_new_and_alloc_extended (domain, format, width, height, 0);
+  return schro_frame_new_and_alloc_full (domain, format, width, height, 0, FALSE);
 }
 
 SchroFrame *
-schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
-    SchroFrameFormat format, int width, int height, int extension)
+schro_frame_new_and_alloc_full (SchroMemoryDomain * domain,
+    SchroFrameFormat format, int width, int height, int extension,
+    int upsampled)
 {
   SchroFrame *frame = schro_frame_new ();
   int bytes_pp;
   int h_shift, v_shift;
   int chroma_width;
   int chroma_height;
-  int ext_width;
-  int ext_height;
 
   SCHRO_ASSERT (width > 0);
   SCHRO_ASSERT (height > 0);
@@ -77,9 +76,7 @@ schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
   frame->height = height;
   frame->domain = domain;
   frame->extension = extension;
-
-  ext_width = width + extension * 2;
-  ext_height = height + extension * 2;
+  frame->is_upsampled = upsampled;
 
   if (SCHRO_FRAME_IS_PACKED (format)) {
     SCHRO_ASSERT (extension == 0);
@@ -134,6 +131,9 @@ schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
   frame->components[0].height = height;
   frame->components[0].stride =
       ROUND_UP_16 ((width + extension * 2) * bytes_pp);
+  if (upsampled) {
+    frame->components[0].stride *= 4;
+  }
   frame->components[0].length =
       frame->components[0].stride * (frame->components[0].height +
       extension * 2);
@@ -145,6 +145,9 @@ schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
   frame->components[1].height = chroma_height;
   frame->components[1].stride =
       ROUND_UP_16 ((chroma_width + extension * 2) * bytes_pp);
+  if (upsampled) {
+    frame->components[1].stride *= 4;
+  }
   frame->components[1].length =
       frame->components[1].stride * (frame->components[1].height +
       extension * 2);
@@ -156,6 +159,9 @@ schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
   frame->components[2].height = chroma_height;
   frame->components[2].stride =
       ROUND_UP_16 ((chroma_width + extension * 2) * bytes_pp);
+  if (upsampled) {
+    frame->components[2].stride *= 4;
+  }
   frame->components[2].length =
       frame->components[2].stride * (frame->components[2].height +
       extension * 2);
@@ -183,6 +189,14 @@ schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
   return frame;
 }
 
+SchroFrame *
+schro_frame_new_and_alloc_extended (SchroMemoryDomain * domain,
+    SchroFrameFormat format, int width, int height, int extension)
+{
+  return schro_frame_new_and_alloc_full (domain, format, width,
+      height, extension, FALSE);
+}
+
 /**
  * schro_frame_new_from_data_YUY2:
  *
@@ -317,6 +331,39 @@ schro_frame_new_from_data_AYUV (void *data, int width, int height)
   return frame;
 }
 
+/**
+ * schro_frame_new_from_data_AY64:
+ *
+ * Creates a new SchroFrame object with the requested size using
+ * the data pointed to by @data.  The data must be in AY64 format.
+ * The data must remain for the lifetime of the SchroFrame object.
+ * It is recommended to use schro_frame_set_free_callback() for
+ * notification when the data is no longer needed.
+ *
+ * Returns: a new SchroFrame object
+ */
+SchroFrame *
+schro_frame_new_from_data_AY64 (void *data, int width, int height)
+{
+  SchroFrame *frame = schro_frame_new ();
+
+  frame->format = SCHRO_FRAME_FORMAT_AY64;
+
+  frame->width = width;
+  frame->height = height;
+
+  frame->components[0].format = frame->format;
+  frame->components[0].width = width;
+  frame->components[0].height = height;
+  frame->components[0].stride = width * 8;
+  frame->components[0].data = data;
+  frame->components[0].length = frame->components[0].stride * height;
+  frame->components[0].v_shift = 0;
+  frame->components[0].h_shift = 0;
+
+  return frame;
+}
+
 /**
  * schro_frame_new_from_data_v216:
  *
@@ -374,7 +421,7 @@ schro_frame_new_from_data_v210 (void *data, int width, int height)
   frame->components[0].format = frame->format;
   frame->components[0].width = width;
   frame->components[0].height = height;
-  frame->components[0].stride = ((width + 5) / 6) * 16;
+  frame->components[0].stride = ((width + 47) / 48) * 128;
   frame->components[0].data = data;
   frame->components[0].length = frame->components[0].stride * height;
   frame->components[0].v_shift = 0;
@@ -511,7 +558,7 @@ schro_frame_new_from_data_Y444 (void *data, int width, int height)
 {
   SchroFrame *frame = schro_frame_new ();
 
-  frame->format = SCHRO_FRAME_FORMAT_U8_420;
+  frame->format = SCHRO_FRAME_FORMAT_U8_444;
 
   frame->width = width;
   frame->height = height;
@@ -623,11 +670,17 @@ schro_frame_dup (SchroFrame * frame)
 
 SchroFrame *
 schro_frame_dup_extended (SchroFrame * frame, int extension)
+{
+  return schro_frame_dup_full (frame, extension, FALSE);
+}
+
+SchroFrame *
+schro_frame_dup_full (SchroFrame * frame, int extension, int is_upsampled)
 {
   SchroFrame *dup_frame;
 
-  dup_frame = schro_frame_new_and_alloc_extended (frame->domain,
-      frame->format, frame->width, frame->height, extension);
+  dup_frame = schro_frame_new_and_alloc_full (frame->domain,
+      frame->format, frame->width, frame->height, extension, is_upsampled);
   schro_frame_convert (dup_frame, frame);
 
   return dup_frame;
@@ -801,6 +854,9 @@ schro_frame_convert (SchroFrame * dest, SchroFrame * src)
     case SCHRO_FRAME_FORMAT_v216:
       dest_format = SCHRO_FRAME_FORMAT_S16_422;
       break;
+    case SCHRO_FRAME_FORMAT_AY64:
+      dest_format = SCHRO_FRAME_FORMAT_S32_444;
+      break;
     default:
       dest_format = dest->format;
       break;
@@ -813,12 +869,21 @@ schro_frame_convert (SchroFrame * dest, SchroFrame * src)
   if (SCHRO_FRAME_FORMAT_DEPTH (dest_format) !=
       SCHRO_FRAME_FORMAT_DEPTH (frame->format)) {
     if (SCHRO_FRAME_FORMAT_DEPTH (dest_format) == SCHRO_FRAME_FORMAT_DEPTH_U8) {
-      frame = schro_virt_frame_new_convert_u8 (frame);
-      SCHRO_DEBUG ("convert_u8 %p", frame);
+      if (SCHRO_FRAME_FORMAT_DEPTH (src->format) == SCHRO_FRAME_FORMAT_DEPTH_S16) {
+        frame = schro_virt_frame_new_convert_u8 (frame);
+        SCHRO_DEBUG ("convert_u8 %p", frame);
+      } else {
+        frame = schro_virt_frame_new_convert_u8_s32 (frame);
+        SCHRO_DEBUG("convert u8 s32");
+      }
     } else if (SCHRO_FRAME_FORMAT_DEPTH (dest_format) ==
         SCHRO_FRAME_FORMAT_DEPTH_S16) {
       frame = schro_virt_frame_new_convert_s16 (frame);
       SCHRO_DEBUG ("convert_s16 %p", frame);
+    } else if (SCHRO_FRAME_FORMAT_DEPTH (dest_format) ==
+        SCHRO_FRAME_FORMAT_DEPTH_S32) {
+      frame = schro_virt_frame_new_convert_s32 (frame);
+      SCHRO_DEBUG ("convert_s32 %p", frame);
     }
   }
 
@@ -860,6 +925,10 @@ schro_frame_convert (SchroFrame * dest, SchroFrame * src)
       frame = schro_virt_frame_new_pack_v216 (frame);
       SCHRO_DEBUG ("pack_v216 %p", frame);
       break;
+    case SCHRO_FRAME_FORMAT_AY64:
+      frame = schro_virt_frame_new_pack_AY64 (frame);
+      SCHRO_DEBUG ("pack_AY64 %p", frame);
+      break;
     default:
       break;
   }
@@ -1118,53 +1187,6 @@ schro_frame_iwt_transform (SchroFrame * frame, SchroParams * params)
   schro_free (tmp);
 }
 
-/**
- * schro_frame_inverse_iwt_transform:
- * @frame: frame
- * @params: transform parameters
- *
- * Performs an in-place inverse integer wavelet transform on @frame.  The
- * frame must have a bit depth of 16.
- */
-void
-schro_frame_inverse_iwt_transform (SchroFrame * frame, SchroParams * params)
-{
-  int width;
-  int height;
-  int level;
-  int component;
-  int16_t *tmp;
-
-  tmp = schro_malloc (sizeof (int16_t) * (params->iwt_luma_width + 16));
-
-  for (component = 0; component < 3; component++) {
-    SchroFrameData *comp = &frame->components[component];
-
-    if (component == 0) {
-      width = params->iwt_luma_width;
-      height = params->iwt_luma_height;
-    } else {
-      width = params->iwt_chroma_width;
-      height = params->iwt_chroma_height;
-    }
-
-    for (level = params->transform_depth - 1; level >= 0; level--) {
-      SchroFrameData fd;
-
-      fd.format = frame->format;
-      fd.data = comp->data;
-      fd.width = width >> level;
-      fd.height = height >> level;
-      fd.stride = comp->stride << level;
-
-      schro_wavelet_inverse_transform_2d (&fd, params->wavelet_filter_index,
-          tmp);
-    }
-  }
-
-  schro_free (tmp);
-}
-
 /**
  * schro_frame_shift_left:
  * @frame: frame
@@ -1203,16 +1225,29 @@ void
 schro_frame_shift_right (SchroFrame * frame, int shift)
 {
   SchroFrameData *comp;
-  int16_t *data;
   int i;
   int y;
 
-  for (i = 0; i < 3; i++) {
-    comp = &frame->components[i];
+  if (SCHRO_FRAME_FORMAT_DEPTH (frame->format) ==
+      SCHRO_FRAME_FORMAT_DEPTH_S16) {
+    int16_t *data;
+    for (i = 0; i < 3; i++) {
+      comp = &frame->components[i];
 
-    for (y = 0; y < comp->height; y++) {
-      data = SCHRO_FRAME_DATA_GET_LINE (comp, y);
-      orc_add_const_rshift_s16 (data, (1 << shift) >> 1, shift, comp->width);
+      for (y = 0; y < comp->height; y++) {
+        data = SCHRO_FRAME_DATA_GET_LINE (comp, y);
+        orc_add_const_rshift_s16 (data, (1 << shift) >> 1, shift, comp->width);
+      }
+    }
+  } else {
+    int32_t *data;
+    for (i = 0; i < 3; i++) {
+      comp = &frame->components[i];
+
+      for (y = 0; y < comp->height; y++) {
+        data = SCHRO_FRAME_DATA_GET_LINE (comp, y);
+        orc_add_const_rshift_s32 (data, (1 << shift) >> 1, shift, comp->width);
+      }
     }
   }
 }
@@ -1787,6 +1822,11 @@ schro_frame_md5 (SchroFrame * frame, uint32_t * state)
     }
   }
 
+  state[0] = uint32_to_host(state[0]);
+  state[1] = uint32_to_host(state[1]);
+  state[2] = uint32_to_host(state[2]);
+  state[3] = uint32_to_host(state[3]);
+
   SCHRO_DEBUG
       ("md5 %02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x%02x",
       state[0] & 0xff, (state[0] >> 8) & 0xff, (state[0] >> 16) & 0xff,
@@ -1807,7 +1847,12 @@ schro_frame_data_get_codeblock (SchroFrameData * dest, SchroFrameData * src,
   int ymax = (src->height * (y + 1)) / vert_codeblocks;
 
   dest->format = src->format;
-  dest->data = SCHRO_FRAME_DATA_GET_PIXEL_S16 (src, xmin, ymin);
+  if (SCHRO_FRAME_FORMAT_DEPTH (src->format) ==
+      SCHRO_FRAME_FORMAT_DEPTH_S32) {
+    dest->data = SCHRO_FRAME_DATA_GET_PIXEL_S32 (src, xmin, ymin);
+  } else {
+    dest->data = SCHRO_FRAME_DATA_GET_PIXEL_S16 (src, xmin, ymin);
+  }
   dest->stride = src->stride;
   dest->width = xmax - xmin;
   dest->height = ymax - ymin;
@@ -1852,6 +1897,7 @@ schro_upsampled_frame_new (SchroFrame * frame)
 
   df = schro_malloc0 (sizeof (SchroUpsampledFrame));
 
+  SCHRO_ASSERT (frame->is_upsampled);
   df->frames[0] = frame;
 
   return df;
@@ -1934,18 +1980,26 @@ schro_frame_mc_edgeextend (SchroFrame * frame)
 void
 schro_upsampled_frame_upsample (SchroUpsampledFrame * df)
 {
+  int i;
+
   if (df->frames[1])
     return;
 
-  df->frames[1] = schro_frame_new_and_alloc_extended (df->frames[0]->domain,
-      df->frames[0]->format, df->frames[0]->width, df->frames[0]->height,
-      df->frames[0]->extension);
-  df->frames[2] = schro_frame_new_and_alloc_extended (df->frames[0]->domain,
-      df->frames[0]->format, df->frames[0]->width, df->frames[0]->height,
-      df->frames[0]->extension);
-  df->frames[3] = schro_frame_new_and_alloc_extended (df->frames[0]->domain,
-      df->frames[0]->format, df->frames[0]->width, df->frames[0]->height,
-      df->frames[0]->extension);
+  for (i=1;i<4;i++){
+    df->frames[i] = schro_frame_new();
+    df->frames[i]->format = df->frames[0]->format;
+    df->frames[i]->width = df->frames[0]->width;
+    df->frames[i]->height = df->frames[0]->height;
+    df->frames[i]->extension = df->frames[0]->extension;
+    memcpy (df->frames[i]->components, df->frames[0]->components,
+        sizeof (SchroFrameData) * 3);
+    df->frames[i]->components[0].data +=
+      (df->frames[i]->components[0].stride >> 2) * i;
+    df->frames[i]->components[1].data +=
+      (df->frames[i]->components[1].stride >> 2) * i;
+    df->frames[i]->components[2].data +=
+      (df->frames[i]->components[2].stride >> 2) * i;
+  }
 
   schro_frame_upsample_vert (df->frames[2], df->frames[0]);
   schro_frame_mc_edgeextend_horiz (df->frames[2], df->frames[2]);
@@ -2222,7 +2276,6 @@ schro_upsampled_frame_get_block_fast_prec3 (SchroUpsampledFrame * upframe,
   SchroFrameData fd01;
   SchroFrameData fd10;
   SchroFrameData fd11;
-  int16_t p[6];
 
   hx = x >> 2;
   hy = y >> 2;
@@ -2288,13 +2341,6 @@ schro_upsampled_frame_get_block_fast_prec3 (SchroUpsampledFrame * upframe,
       __schro_upsampled_frame_get_subdata_prec1 (upframe, k, hx + 1, hy + 1,
           &fd11);
 
-      p[0] = w00;
-      p[1] = w01;
-      p[2] = w10;
-      p[3] = w11;
-      p[4] = 8;
-      p[5] = 4;
-
       switch (fd->width) {
 #if 0
         case 8:
@@ -2446,3 +2492,20 @@ schro_frame_get_reference_subdata (SchroFrame * frame, SchroFrameData * fd,
   fd->width = MAX (0, comp->width + extension - x);
   fd->height = MAX (0, comp->height + extension - y);
 }
+
+int schro_frame_get_bit_depth (SchroFrame *frame)
+{
+  if (frame->format == SCHRO_FRAME_FORMAT_v210) {
+    return 10;
+  }
+  switch (SCHRO_FRAME_FORMAT_DEPTH(frame->format)) {
+    case SCHRO_FRAME_FORMAT_DEPTH_U8:
+      return 8;
+    case SCHRO_FRAME_FORMAT_DEPTH_S16:
+      return 16;
+    case SCHRO_FRAME_FORMAT_DEPTH_S32:
+      return 32;
+  }
+  return 0;
+}
+
