@@ -8,15 +8,15 @@
 int _schro_motion_ref = FALSE;
 
 static int
-get_pixel (SchroMotion *motion, int k, SchroUpsampledFrame *upframe,
+get_pixel (SchroMotion * motion, int k, SchroUpsampledFrame * upframe,
     int x, int y, int dx, int dy);
 
 int
-schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
+schro_motion_pixel_predict_block (SchroMotion * motion, int x, int y, int k,
     int i, int j);
 
 static void
-schro_motion_get_global_vector (SchroMotion *motion, int ref, int x, int y,
+schro_motion_get_global_vector (SchroMotion * motion, int ref, int x, int y,
     int *dx, int *dy)
 {
   SchroParams *params = motion->params;
@@ -27,20 +27,20 @@ schro_motion_get_global_vector (SchroMotion *motion, int ref, int x, int y,
   alpha = gm->a_exp;
   beta = gm->c_exp;
 
-  scale = (1<<beta) - (gm->c0 * x + gm->c1 * y);
+  scale = (1 << beta) - (gm->c0 * x + gm->c1 * y);
 
-  *dx = scale * (gm->a00 * x + gm->a01 * y + (1<<alpha) * gm->b0);
-  *dy = scale * (gm->a10 * x + gm->a11 * y + (1<<alpha) * gm->b1);
+  *dx = scale * (gm->a00 * x + gm->a01 * y + (1 << alpha) * gm->b0);
+  *dy = scale * (gm->a10 * x + gm->a11 * y + (1 << alpha) * gm->b1);
 
-  *dx >>= (alpha+beta);
-  *dy >>= (alpha+beta);
+  *dx >>= (alpha + beta);
+  *dy >>= (alpha + beta);
 }
 
 
 static int
-schro_motion_pixel_predict (SchroMotion *motion, int x, int y, int k)
+schro_motion_pixel_predict (SchroMotion * motion, int x, int y, int k)
 {
-  int i,j;
+  int i, j;
   int value;
 
   i = (x + motion->xoffset) / motion->xbsep - 1;
@@ -51,29 +51,29 @@ schro_motion_pixel_predict (SchroMotion *motion, int x, int y, int k)
   value += schro_motion_pixel_predict_block (motion, x, y, k, i, j + 1);
   value += schro_motion_pixel_predict_block (motion, x, y, k, i + 1, j + 1);
 
-  return ROUND_SHIFT(value, 6);
+  return ROUND_SHIFT (value, 6);
 }
 
 static int
-get_dc_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
+get_dc_pixel (SchroMotion * motion, int i, int j, int k, int x, int y)
 {
   SchroParams *params = motion->params;
   SchroMotionVector *mv;
 
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
+  mv = &motion->motion_vectors[j * params->x_num_blocks + i];
 
   return mv->u.dc.dc[k] + 128;
 }
 
 static int
-get_ref1_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
+get_ref1_pixel (SchroMotion * motion, int i, int j, int k, int x, int y)
 {
   SchroParams *params = motion->params;
   SchroMotionVector *mv;
   int value;
   int dx, dy;
 
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
+  mv = &motion->motion_vectors[j * params->x_num_blocks + i];
   if (mv->using_global) {
     schro_motion_get_global_vector (motion, 0, x, y, &dx, &dy);
   } else {
@@ -84,18 +84,18 @@ get_ref1_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
   value = (motion->ref1_weight + motion->ref2_weight) *
       get_pixel (motion, k, motion->src1, x, y, dx, dy);
 
-  return ROUND_SHIFT(value, motion->ref_weight_precision);
+  return ROUND_SHIFT (value, motion->ref_weight_precision);
 }
 
 static int
-get_ref2_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
+get_ref2_pixel (SchroMotion * motion, int i, int j, int k, int x, int y)
 {
   SchroParams *params = motion->params;
   SchroMotionVector *mv;
   int value;
   int dx, dy;
 
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
+  mv = &motion->motion_vectors[j * params->x_num_blocks + i];
   if (mv->using_global) {
     schro_motion_get_global_vector (motion, 1, x, y, &dx, &dy);
   } else {
@@ -106,18 +106,18 @@ get_ref2_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
   value = (motion->ref1_weight + motion->ref2_weight) *
       get_pixel (motion, k, motion->src2, x, y, dx, dy);
 
-  return ROUND_SHIFT(value, motion->ref_weight_precision);
+  return ROUND_SHIFT (value, motion->ref_weight_precision);
 }
 
 static int
-get_biref_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
+get_biref_pixel (SchroMotion * motion, int i, int j, int k, int x, int y)
 {
   SchroParams *params = motion->params;
   SchroMotionVector *mv;
   int value;
   int dx0, dx1, dy0, dy1;
 
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
+  mv = &motion->motion_vectors[j * params->x_num_blocks + i];
   if (mv->using_global) {
     schro_motion_get_global_vector (motion, 0, x, y, &dx0, &dy0);
     schro_motion_get_global_vector (motion, 1, x, y, &dx1, &dy1);
@@ -129,22 +129,24 @@ get_biref_pixel (SchroMotion *motion, int i, int j, int k, int x, int y)
   }
 
   value = motion->ref1_weight *
-    get_pixel (motion, k, motion->src1, x, y, dx0, dy0);
+      get_pixel (motion, k, motion->src1, x, y, dx0, dy0);
   value += motion->ref2_weight *
-    get_pixel (motion, k, motion->src2, x, y, dx1, dy1);
+      get_pixel (motion, k, motion->src2, x, y, dx1, dy1);
 
-  return ROUND_SHIFT(value, motion->ref_weight_precision);
+  return ROUND_SHIFT (value, motion->ref_weight_precision);
 }
 
 static int
-get_pixel (SchroMotion *motion, int k, SchroUpsampledFrame *upframe,
+get_pixel (SchroMotion * motion, int k, SchroUpsampledFrame * upframe,
     int x, int y, int dx, int dy)
 {
   int px, py;
 
   if (k > 0) {
-    dx >>= SCHRO_CHROMA_FORMAT_H_SHIFT(motion->params->video_format->chroma_format);
-    dy >>= SCHRO_CHROMA_FORMAT_V_SHIFT(motion->params->video_format->chroma_format);
+    dx >>= SCHRO_CHROMA_FORMAT_H_SHIFT (motion->params->
+        video_format->chroma_format);
+    dy >>= SCHRO_CHROMA_FORMAT_V_SHIFT (motion->params->
+        video_format->chroma_format);
   }
 
   px = (x << motion->mv_precision) + dx;
@@ -158,14 +160,15 @@ static int
 get_ramp (int x, int offset)
 {
   if (offset == 1) {
-    if (x == 0) return 3;
+    if (x == 0)
+      return 3;
     return 5;
   }
-  return 1 + (6 * x + offset - 1)/(2*offset - 1);
+  return 1 + (6 * x + offset - 1) / (2 * offset - 1);
 }
 
 int
-schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
+schro_motion_pixel_predict_block (SchroMotion * motion, int x, int y, int k,
     int i, int j)
 {
   SchroParams *params = motion->params;
@@ -175,26 +178,29 @@ schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
   int value;
   int width, height;
 
-  if (i < 0 || j < 0) return 0;
-  if (i >= params->x_num_blocks || j >= params->y_num_blocks) return 0;
+  if (i < 0 || j < 0)
+    return 0;
+  if (i >= params->x_num_blocks || j >= params->y_num_blocks)
+    return 0;
 
   width = motion->xbsep * params->x_num_blocks;
   height = motion->ybsep * params->y_num_blocks;
 
   xmin = i * motion->xbsep - motion->xoffset;
   ymin = j * motion->ybsep - motion->yoffset;
-  xmax = (i+1) * motion->xbsep + motion->xoffset;
-  ymax = (j+1) * motion->ybsep + motion->yoffset;
+  xmax = (i + 1) * motion->xbsep + motion->xoffset;
+  ymax = (j + 1) * motion->ybsep + motion->yoffset;
 
-  if (x < xmin || y < ymin || x >= xmax || y >= ymax) return 0;
+  if (x < xmin || y < ymin || x >= xmax || y >= ymax)
+    return 0;
 
   if (motion->xoffset == 0) {
     wx = 8;
   } else if (x < motion->xoffset || x >= width - motion->xoffset) {
     wx = 8;
-  } else if (x - xmin < 2*motion->xoffset) {
+  } else if (x - xmin < 2 * motion->xoffset) {
     wx = get_ramp (x - xmin, motion->xoffset);
-  } else if (xmax - 1 - x < 2*motion->xoffset) {
+  } else if (xmax - 1 - x < 2 * motion->xoffset) {
     wx = get_ramp (xmax - 1 - x, motion->xoffset);
   } else {
     wx = 8;
@@ -204,15 +210,15 @@ schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
     wy = 8;
   } else if (y < motion->yoffset || y >= height - motion->yoffset) {
     wy = 8;
-  } else if (y - ymin < 2*motion->yoffset) {
+  } else if (y - ymin < 2 * motion->yoffset) {
     wy = get_ramp (y - ymin, motion->yoffset);
-  } else if (ymax - 1 - y < 2*motion->yoffset) {
+  } else if (ymax - 1 - y < 2 * motion->yoffset) {
     wy = get_ramp (ymax - 1 - y, motion->yoffset);
   } else {
     wy = 8;
   }
 
-  mv = &motion->motion_vectors[j*params->x_num_blocks + i];
+  mv = &motion->motion_vectors[j * params->x_num_blocks + i];
 
   switch (mv->pred_mode) {
     case 0:
@@ -237,18 +243,18 @@ schro_motion_pixel_predict_block (SchroMotion *motion, int x, int y, int k,
 
 
 void
-schro_motion_render_ref (SchroMotion *motion, SchroFrame *dest,
-    SchroFrame *addframe, int add, SchroFrame *output_frame)
+schro_motion_render_ref (SchroMotion * motion, SchroFrame * dest,
+    SchroFrame * addframe, int add, SchroFrame * output_frame)
 {
   SchroParams *params = motion->params;
   int k;
-  int x,y;
+  int x, y;
   int16_t *line;
   int16_t *addline;
   uint8_t *oline;
 
   if (params->num_refs == 1) {
-    SCHRO_ASSERT(params->picture_weight_2 == 1);
+    SCHRO_ASSERT (params->picture_weight_2 == 1);
   }
 
   motion->ref_weight_precision = params->picture_weight_bits;
@@ -257,7 +263,7 @@ schro_motion_render_ref (SchroMotion *motion, SchroFrame *dest,
 
   motion->mv_precision = params->mv_precision;
 
-  for(k=0;k<3;k++){
+  for (k = 0; k < 3; k++) {
     SchroFrameData *comp = dest->components + k;
 
     if (k == 0) {
@@ -267,21 +273,25 @@ schro_motion_render_ref (SchroMotion *motion, SchroFrame *dest,
       motion->yblen = params->yblen_luma;
     } else {
       motion->xbsep = params->xbsep_luma >>
-        SCHRO_CHROMA_FORMAT_H_SHIFT(motion->params->video_format->chroma_format);
-      motion->ybsep = params->ybsep_luma >>
-        SCHRO_CHROMA_FORMAT_V_SHIFT(motion->params->video_format->chroma_format);
-      motion->xblen = params->xblen_luma >>
-        SCHRO_CHROMA_FORMAT_H_SHIFT(motion->params->video_format->chroma_format);
-      motion->yblen = params->yblen_luma >>
-        SCHRO_CHROMA_FORMAT_V_SHIFT(motion->params->video_format->chroma_format);
+          SCHRO_CHROMA_FORMAT_H_SHIFT (motion->params->
+          video_format->chroma_format);
+      motion->ybsep =
+          params->ybsep_luma >> SCHRO_CHROMA_FORMAT_V_SHIFT (motion->
+          params->video_format->chroma_format);
+      motion->xblen =
+          params->xblen_luma >> SCHRO_CHROMA_FORMAT_H_SHIFT (motion->
+          params->video_format->chroma_format);
+      motion->yblen =
+          params->yblen_luma >> SCHRO_CHROMA_FORMAT_V_SHIFT (motion->
+          params->video_format->chroma_format);
     }
-    motion->xoffset = (motion->xblen - motion->xbsep)/2;
-    motion->yoffset = (motion->yblen - motion->ybsep)/2;
+    motion->xoffset = (motion->xblen - motion->xbsep) / 2;
+    motion->yoffset = (motion->yblen - motion->ybsep) / 2;
 
-    for(y=0;y<comp->height;y++){
-      line = SCHRO_FRAME_DATA_GET_LINE(comp, y);
-      for(x=0;x<comp->width;x++){
-        line[x] = CLAMP(schro_motion_pixel_predict (motion, x, y, k), 0, 255);
+    for (y = 0; y < comp->height; y++) {
+      line = SCHRO_FRAME_DATA_GET_LINE (comp, y);
+      for (x = 0; x < comp->width; x++) {
+        line[x] = CLAMP (schro_motion_pixel_predict (motion, x, y, k), 0, 255);
 
         /* Note: the 128 offset converts the 0-255 range of the reference
          * pictures into the bipolar range used for Dirac signal processing */
@@ -290,25 +300,24 @@ schro_motion_render_ref (SchroMotion *motion, SchroFrame *dest,
     }
 
     if (add) {
-      for(y=0;y<comp->height;y++){
-        line = SCHRO_FRAME_DATA_GET_LINE(comp, y);
-        addline = SCHRO_FRAME_DATA_GET_LINE(addframe->components+k, y);
-        oline = SCHRO_FRAME_DATA_GET_LINE(output_frame->components+k, y);
+      for (y = 0; y < comp->height; y++) {
+        line = SCHRO_FRAME_DATA_GET_LINE (comp, y);
+        addline = SCHRO_FRAME_DATA_GET_LINE (addframe->components + k, y);
+        oline = SCHRO_FRAME_DATA_GET_LINE (output_frame->components + k, y);
 
-        for(x=0;x<comp->width;x++){
-          oline[x] = CLAMP(addline[x] + line[x] + 128, 0, 255);
+        for (x = 0; x < comp->width; x++) {
+          oline[x] = CLAMP (addline[x] + line[x] + 128, 0, 255);
         }
       }
     } else {
-      for(y=0;y<comp->height;y++){
-        line = SCHRO_FRAME_DATA_GET_LINE(comp, y);
-        addline = SCHRO_FRAME_DATA_GET_LINE(addframe->components+k, y);
+      for (y = 0; y < comp->height; y++) {
+        line = SCHRO_FRAME_DATA_GET_LINE (comp, y);
+        addline = SCHRO_FRAME_DATA_GET_LINE (addframe->components + k, y);
 
-        for(x=0;x<comp->width;x++){
+        for (x = 0; x < comp->width; x++) {
           addline[x] -= line[x];
         }
       }
     }
   }
 }
-
