@@ -338,8 +338,12 @@ schro_encoder_choose_quantisers_simple (SchroEncoderFrame * frame)
   double a;
   double max;
   double *table;
+  double range;
 
-  noise_amplitude = 255.0 * pow (0.1, frame->encoder->noise_threshold * 0.05);
+  /* FIXME this should really be based directly on excursion */
+  range = (1<<frame->encoder->bit_depth) - 1.0;
+
+  noise_amplitude = range * pow (0.1, frame->encoder->noise_threshold * 0.05);
   SCHRO_DEBUG ("noise %g", noise_amplitude);
 
   if (frame->num_refs == 0) {
@@ -707,7 +711,6 @@ schro_encoder_calc_estimates (SchroEncoderFrame * frame)
 
     for (i = 0; i < 1 + 3 * params->transform_depth; i++) {
       for (j = 0; j < 60; j++) {
-        int vol;
         int position;
         SchroHistogram *hist;
         SchroFrameData fd;
@@ -715,7 +718,6 @@ schro_encoder_calc_estimates (SchroEncoderFrame * frame)
         position = schro_subband_get_position (i);
         schro_subband_get_frame_data (&fd, frame->iwt_frame, component,
             position, &frame->params);
-        vol = fd.width * fd.height;
 
         hist = &frame->subband_hists[component][i];
         frame->est_entropy[component][i][j] =
@@ -771,29 +773,12 @@ schro_encoder_choose_quantisers_rdo_lambda (SchroEncoderFrame * frame)
 void
 schro_encoder_choose_quantisers_rdo_cbr (SchroEncoderFrame * frame)
 {
-  int est_bits, alloc_bits;
-  SchroEncoder *encoder = frame->encoder;
-
   schro_encoder_generate_subband_histograms (frame);
   schro_encoder_calc_estimates (frame);
 
   SCHRO_ASSERT (frame->have_estimate_tables);
 
-  est_bits =
-      (int) (schro_encoder_lambda_to_entropy (frame, frame->frame_lambda));
-
-  // SCHRO_ERROR("Estimated bits for frame %d residual : %d", frame>frame_number, est_bits);
-
-  // Check that we're within reasonable bounds of the allocation
-
-  if (frame->num_refs == 0) {
-    alloc_bits = encoder->I_frame_alloc;
-  } else if (schro_encoder_frame_is_B_frame (frame) == TRUE) {
-    alloc_bits = encoder->B_frame_alloc;
-  } else {
-    alloc_bits = encoder->P_frame_alloc;
-  }
-
+  schro_encoder_lambda_to_entropy (frame, frame->frame_lambda);
 }
 
 void
