@@ -2,7 +2,18 @@
 #ifndef __SCHRO_UTILS_H__
 #define __SCHRO_UTILS_H__
 
-#include <schroedinger/schro-stdint.h>
+#if defined(_MSC_VER)
+#ifndef SCHRO_NO_STDINT_TYPEDEFS
+typedef __int8 int8_t;
+typedef __int16 int16_t;
+typedef __int32 int32_t;
+typedef unsigned __int8 uint8_t;
+typedef unsigned __int16 uint16_t;
+typedef unsigned __int32 uint32_t;
+#endif
+#else
+#include <stdint.h>
+#endif
 
 #ifndef TRUE
 #define TRUE 1
@@ -21,6 +32,10 @@ typedef int SchroCUDAStream;
 
 #ifdef SCHRO_ENABLE_UNSTABLE_API
 
+#if defined(_MSC_VER)
+#define inline __inline
+#endif
+
 #define SCHRO_PICTURE_NUMBER_INVALID (-1)
 
 #define ARRAY_SIZE(x) (sizeof(x)/sizeof(x[0]))
@@ -40,11 +55,13 @@ typedef int SchroCUDAStream;
 #define ROUND_UP_2(x) ROUND_UP_POW2(x,1)
 #define ROUND_UP_4(x) ROUND_UP_POW2(x,2)
 #define ROUND_UP_8(x) ROUND_UP_POW2(x,3)
+#define ROUND_UP_16(x) ROUND_UP_POW2(x,4)
 #define ROUND_UP_64(x) ROUND_UP_POW2(x,6)
 #define OFFSET(ptr,offset) ((void *)(((uint8_t *)(ptr)) + (offset)))
 #define ROUND_SHIFT(x,y) (((x) + (1<<((y)-1)))>>(y))
 
 #define schro_divide(a,b) (((a)<0)?(((a) - (b) + 1)/(b)):((a)/(b)))
+#define schro_divide3(a) (((a)*21845 + 10922)>>16)
 
 #endif
 
@@ -57,13 +74,25 @@ typedef int SchroCUDAStream;
 #else
 #define SCHRO_GNUC_PREREQ(maj, min) 0
 #endif
-  
+
 #if SCHRO_GNUC_PREREQ(3,3) && defined(__ELF__)
 #define SCHRO_INTERNAL __attribute__ ((visibility ("internal")))
 #else
 #define SCHRO_INTERNAL
 #endif
 
+#if SCHRO_GNUC_PREREQ(3,3)
+#define SCHRO_DEPRECATED __attribute__ ((deprecated))
+#else
+#define SCHRO_DEPRECATED
+#endif
+
+#if SCHRO_GNUC_PREREQ(3,3)
+#define SCHRO_UNUSED __attribute__ ((unused))
+#else
+#define SCHRO_UNUSED
+#endif
+
 #ifdef __cplusplus
 #define SCHRO_BEGIN_DECLS extern "C" {
 #define SCHRO_END_DECLS }
@@ -72,6 +101,24 @@ typedef int SchroCUDAStream;
 #define SCHRO_END_DECLS
 #endif
 
+#if SCHRO_GNUC_PREREQ(3,0) && defined(__OPTIMIZE__)
+#define SCHRO_LIKELY(expr) (__builtin_expect ((expr), 1))
+#define SCHRO_UNLIKELY(expr) (__builtin_expect ((expr), 0))
+#else
+#define SCHRO_LIKELY(expr) (expr)
+#define SCHRO_UNLIKELY(expr) (expr)
+#endif
+
+#ifndef M_PI
+#define M_PI 3.14159265358979323846
+#endif
+#ifndef M_LN10
+#define M_LN10 2.30258509299404568402
+#endif
+
+#if defined(_MSC_VER)
+#define rint(x) (floor((x) + 0.5))
+#endif
 
 SCHRO_BEGIN_DECLS
 
@@ -88,8 +135,14 @@ int schro_dequantise (int q, int quant_factor, int quant_offset);
 int schro_quantise (int value, int quant_factor, int quant_offset);
 void schro_quantise_s16 (int16_t *dest, int16_t *src, int quant_factor,
     int quant_offset, int n);
+void schro_quantise_s32 (int32_t *dest, int32_t *src, int quant_factor,
+    int quant_offset, int n);
+void schro_quantise_s16_table (int16_t *dest, int16_t *src, int quant_index,
+    schro_bool is_intra, int n);
 void schro_dequantise_s16 (int16_t *dest, int16_t *src, int quant_factor,
     int quant_offset, int n);
+void schro_dequantise_s16_table (int16_t *dest, int16_t *src, int quant_index,
+    schro_bool is_intra, int n);
 double schro_utils_probability_to_entropy (double x);
 double schro_utils_entropy (double a, double total);
 void schro_utils_reduce_fraction (int *n, int *d);
