@@ -17,36 +17,38 @@
  * Returns: TRUE if the contents of @format is valid
  */
 int
-schro_video_format_validate (SchroVideoFormat *format)
+schro_video_format_validate (SchroVideoFormat * format)
 {
   int fix_clean_area = 0;
 
   if (format->aspect_ratio_numerator == 0) {
-    SCHRO_ERROR("aspect_ratio_numerator is 0");
+    SCHRO_ERROR ("aspect_ratio_numerator is 0");
     format->aspect_ratio_numerator = 1;
   }
   if (format->aspect_ratio_denominator == 0) {
-    SCHRO_ERROR("aspect_ratio_denominator is 0");
+    SCHRO_ERROR ("aspect_ratio_denominator is 0");
     format->aspect_ratio_denominator = 1;
   }
 
   if (format->clean_width + format->left_offset > format->width) {
-    SCHRO_ERROR("10.3.7: horizontal clean area is not legal (clean_width + left_offset > width)");
+    SCHRO_ERROR
+        ("10.3.7: horizontal clean area is not legal (clean_width + left_offset > width)");
     fix_clean_area = 1;
   }
   if (format->clean_height + format->top_offset > format->height) {
-    SCHRO_ERROR("10.3.7: vertical clean area is not legal (clean_height + top_offset > height)");
+    SCHRO_ERROR
+        ("10.3.7: vertical clean area is not legal (clean_height + top_offset > height)");
     fix_clean_area = 1;
   }
   if (fix_clean_area) {
-    SCHRO_ERROR("resetting clean area to frame size");
+    SCHRO_ERROR ("resetting clean area to frame size");
     format->clean_width = format->width;
     format->clean_height = format->height;
     format->left_offset = format->top_offset = 0;
   }
 
   if (schro_video_format_get_bit_depth (format) != 8) {
-    SCHRO_WARNING("video bit depth != 8");
+    SCHRO_WARNING ("video bit depth != 8");
     return 0;
   }
 
@@ -55,7 +57,8 @@ schro_video_format_validate (SchroVideoFormat *format)
 
 #ifdef unused
 int
-schro_video_format_compare_new_sequence (SchroVideoFormat *a, SchroVideoFormat *b)
+schro_video_format_compare_new_sequence (SchroVideoFormat * a,
+    SchroVideoFormat * b)
 {
   if (a->index != b->index ||
       a->width != b->width ||
@@ -86,7 +89,7 @@ schro_video_format_compare_new_sequence (SchroVideoFormat *a, SchroVideoFormat *
 
 #ifdef unused
 int
-schro_video_format_compare (SchroVideoFormat *a, SchroVideoFormat *b)
+schro_video_format_compare (SchroVideoFormat * a, SchroVideoFormat * b)
 {
   if (!schro_video_format_compare_new_sequence (a, b) ||
       a->interlaced_coding != b->interlaced_coding) {
@@ -97,168 +100,168 @@ schro_video_format_compare (SchroVideoFormat *a, SchroVideoFormat *b)
 #endif
 
 int
-schro_video_format_get_bit_depth (SchroVideoFormat *format)
+schro_video_format_get_bit_depth (SchroVideoFormat * format)
 {
   int max;
   int i;
 
-  max = MAX(format->chroma_excursion, format->luma_excursion);
+  max = MAX (format->chroma_excursion, format->luma_excursion);
 
-  for(i=0;i<32;i++) {
-    if (max < (1<<i)) return i;
+  for (i = 0; i < 32; i++) {
+    if (max < (1 << i))
+      return i;
   }
   return 0;
 }
 
-static SchroVideoFormat
-schro_video_formats[] = {
-  { 0, /* custom */
-    640, 480, SCHRO_CHROMA_420,
-    FALSE, FALSE,
-    24000, 1001, 1, 1,
-    640, 480, 0, 0,
-    0, 255, 128, 255,
-    0, 0, 0 },
-  { 1, /* QSIF525 */
-    176, 120, SCHRO_CHROMA_420,
-    FALSE, FALSE,
-    15000, 1001, 10, 11,
-    176, 120, 0, 0,
-    0, 255, 128, 255,
-    1, 1, 0 },
-  { 2, /* QCIF */
-    176, 144, SCHRO_CHROMA_420,
-    FALSE, TRUE,
-    25, 2, 12, 11,
-    176, 144, 0, 0,
-    0, 255, 128, 255,
-    2, 1, 0 },
-  { 3, /* SIF525 */
-    352, 240, SCHRO_CHROMA_420,
-    FALSE, FALSE,
-    15000, 1001, 10, 11,
-    352, 240, 0, 0,
-    0, 255, 128, 255,
-    1, 1, 0 },
-  { 4, /* CIF */
-    352, 288, SCHRO_CHROMA_420,
-    FALSE, TRUE,
-    25, 2, 12, 11,
-    352, 288, 0, 0,
-    0, 255, 128, 255,
-    2, 1, 0 },
-  { 5, /* 4SIF525 */
-    704, 480, SCHRO_CHROMA_420,
-    FALSE, FALSE,
-    15000, 1001, 10, 11,
-    704, 480, 0, 0,
-    0, 255, 128, 255,
-    1, 1, 0 },
-  { 6, /* 4CIF */
-    704, 576, SCHRO_CHROMA_420,
-    FALSE, TRUE,
-    25, 2, 12, 11,
-    704, 576, 0, 0,
-    0, 255, 128, 255,
-    2, 1, 0 },
-  { 7, /* SD480I-60 */
-    720, 480, SCHRO_CHROMA_422,
-    TRUE, FALSE,
-    30000, 1001, 10, 11,
-    704, 480, 8, 0,
-    64, 876, 512, 896,
-    1, 1, 0 },
-  { 8, /* SD576I-50 */
-    720, 576, SCHRO_CHROMA_422,
-    TRUE, TRUE,
-    25, 1, 12, 11,
-    704, 576, 8, 0,
-    64, 876, 512, 896,
-    2, 1, 0 },
-  { 9, /* HD720P-60 */
-    1280, 720, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    60000, 1001, 1, 1,
-    1280, 720, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 10, /* HD720P-50 */
-    1280, 720, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    50, 1, 1, 1,
-    1280, 720, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 11, /* HD1080I-60 */
-    1920, 1080, SCHRO_CHROMA_422,
-    TRUE, TRUE,
-    30000, 1001, 1, 1,
-    1920, 1080, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 12, /* HD1080I-50 */
-    1920, 1080, SCHRO_CHROMA_422,
-    TRUE, TRUE,
-    25, 1, 1, 1,
-    1920, 1080, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 13, /* HD1080P-60 */
-    1920, 1080, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    60000, 1001, 1, 1,
-    1920, 1080, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 14, /* HD1080P-50 */
-    1920, 1080, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    50, 1, 1, 1,
-    1920, 1080, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 15, /* DC2K */
-    2048, 1080, SCHRO_CHROMA_444,
-    FALSE, TRUE,
-    24, 1, 1, 1,
-    2048, 1080, 0, 0,
-    256, 3504, 2048, 3584,
-    3, 0, 0 },
-  { 16, /* DC4K */
-    4096, 2160, SCHRO_CHROMA_444,
-    FALSE, TRUE,
-    24, 1, 1, 1,
-    2048, 1536, 0, 0,
-    256, 3504, 2048, 3584,
-    3, 0, 0 },
-  { 17, /* UHDTV 4K-60  */
-    3840, 2160, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    60000, 1001, 1, 1,
-    3840, 2160, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 18, /* UHDTV 4K-50 */
-    3840, 2160, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    50, 1, 1, 1,
-    3840, 2160, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 19, /* UHDTV 8K-60 */
-    7680, 4320, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    60000, 1001, 1, 1,
-    7680, 4320, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
-  { 20, /* UHDTV 8K-50 */
-    7680, 4320, SCHRO_CHROMA_422,
-    FALSE, TRUE,
-    50, 1, 1, 1,
-    7680, 4320, 0, 0,
-    64, 876, 512, 896,
-    0, 0, 0 },
+static SchroVideoFormat schro_video_formats[] = {
+  {0,                           /* custom */
+        640, 480, SCHRO_CHROMA_420,
+        FALSE, FALSE,
+        24000, 1001, 1, 1,
+        640, 480, 0, 0,
+        0, 255, 128, 255,
+      0, 0, 0},
+  {1,                           /* QSIF525 */
+        176, 120, SCHRO_CHROMA_420,
+        FALSE, FALSE,
+        15000, 1001, 10, 11,
+        176, 120, 0, 0,
+        0, 255, 128, 255,
+      1, 1, 0},
+  {2,                           /* QCIF */
+        176, 144, SCHRO_CHROMA_420,
+        FALSE, TRUE,
+        25, 2, 12, 11,
+        176, 144, 0, 0,
+        0, 255, 128, 255,
+      2, 1, 0},
+  {3,                           /* SIF525 */
+        352, 240, SCHRO_CHROMA_420,
+        FALSE, FALSE,
+        15000, 1001, 10, 11,
+        352, 240, 0, 0,
+        0, 255, 128, 255,
+      1, 1, 0},
+  {4,                           /* CIF */
+        352, 288, SCHRO_CHROMA_420,
+        FALSE, TRUE,
+        25, 2, 12, 11,
+        352, 288, 0, 0,
+        0, 255, 128, 255,
+      2, 1, 0},
+  {5,                           /* 4SIF525 */
+        704, 480, SCHRO_CHROMA_420,
+        FALSE, FALSE,
+        15000, 1001, 10, 11,
+        704, 480, 0, 0,
+        0, 255, 128, 255,
+      1, 1, 0},
+  {6,                           /* 4CIF */
+        704, 576, SCHRO_CHROMA_420,
+        FALSE, TRUE,
+        25, 2, 12, 11,
+        704, 576, 0, 0,
+        0, 255, 128, 255,
+      2, 1, 0},
+  {7,                           /* SD480I-60 */
+        720, 480, SCHRO_CHROMA_422,
+        TRUE, FALSE,
+        30000, 1001, 10, 11,
+        704, 480, 8, 0,
+        64, 876, 512, 896,
+      1, 1, 0},
+  {8,                           /* SD576I-50 */
+        720, 576, SCHRO_CHROMA_422,
+        TRUE, TRUE,
+        25, 1, 12, 11,
+        704, 576, 8, 0,
+        64, 876, 512, 896,
+      2, 1, 0},
+  {9,                           /* HD720P-60 */
+        1280, 720, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        60000, 1001, 1, 1,
+        1280, 720, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {10,                          /* HD720P-50 */
+        1280, 720, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        50, 1, 1, 1,
+        1280, 720, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {11,                          /* HD1080I-60 */
+        1920, 1080, SCHRO_CHROMA_422,
+        TRUE, TRUE,
+        30000, 1001, 1, 1,
+        1920, 1080, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {12,                          /* HD1080I-50 */
+        1920, 1080, SCHRO_CHROMA_422,
+        TRUE, TRUE,
+        25, 1, 1, 1,
+        1920, 1080, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {13,                          /* HD1080P-60 */
+        1920, 1080, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        60000, 1001, 1, 1,
+        1920, 1080, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {14,                          /* HD1080P-50 */
+        1920, 1080, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        50, 1, 1, 1,
+        1920, 1080, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {15,                          /* DC2K */
+        2048, 1080, SCHRO_CHROMA_444,
+        FALSE, TRUE,
+        24, 1, 1, 1,
+        2048, 1080, 0, 0,
+        256, 3504, 2048, 3584,
+      3, 0, 0},
+  {16,                          /* DC4K */
+        4096, 2160, SCHRO_CHROMA_444,
+        FALSE, TRUE,
+        24, 1, 1, 1,
+        2048, 1536, 0, 0,
+        256, 3504, 2048, 3584,
+      3, 0, 0},
+  {17,                          /* UHDTV 4K-60  */
+        3840, 2160, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        60000, 1001, 1, 1,
+        3840, 2160, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {18,                          /* UHDTV 4K-50 */
+        3840, 2160, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        50, 1, 1, 1,
+        3840, 2160, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {19,                          /* UHDTV 8K-60 */
+        7680, 4320, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        60000, 1001, 1, 1,
+        7680, 4320, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
+  {20,                          /* UHDTV 8K-50 */
+        7680, 4320, SCHRO_CHROMA_422,
+        FALSE, TRUE,
+        50, 1, 1, 1,
+        7680, 4320, 0, 0,
+        64, 876, 512, 896,
+      0, 0, 0},
 };
 
 /**
@@ -270,19 +273,19 @@ schro_video_formats[] = {
  * the standard Dirac video formats specified by @index.
  */
 void
-schro_video_format_set_std_video_format (SchroVideoFormat *format,
+schro_video_format_set_std_video_format (SchroVideoFormat * format,
     SchroVideoFormatEnum index)
 {
-  if (index < 0 || index >= ARRAY_SIZE(schro_video_formats)) {
-    SCHRO_ERROR("illegal video format index");
+  if (index < 0 || index >= ARRAY_SIZE (schro_video_formats)) {
+    SCHRO_ERROR ("illegal video format index");
     return;
   }
 
-  memcpy (format, schro_video_formats + index, sizeof(SchroVideoFormat));
+  memcpy (format, schro_video_formats + index, sizeof (SchroVideoFormat));
 }
 
 static int
-schro_video_format_get_video_format_metric (SchroVideoFormat *format, int i)
+schro_video_format_get_video_format_metric (SchroVideoFormat * format, int i)
 {
   SchroVideoFormat *std_format;
   int metric = 0;
@@ -290,7 +293,7 @@ schro_video_format_get_video_format_metric (SchroVideoFormat *format, int i)
   std_format = schro_video_formats + i;
 
   /* this is really important because it can't be overrided */
-  if (format->interlaced && 
+  if (format->interlaced &&
       format->top_field_first == std_format->top_field_first) {
     metric |= 0x8000;
   }
@@ -329,7 +332,7 @@ schro_video_format_get_video_format_metric (SchroVideoFormat *format, int i)
     metric++;
     i = schro_video_format_get_std_frame_rate (format);
     metric += schro_pack_estimate_uint (i);
-    if (i==0) {
+    if (i == 0) {
       metric += schro_pack_estimate_uint (format->frame_rate_numerator);
       metric += schro_pack_estimate_uint (format->frame_rate_denominator);
     }
@@ -337,13 +340,14 @@ schro_video_format_get_video_format_metric (SchroVideoFormat *format, int i)
 
   /* pixel aspect ratio */
   if (std_format->aspect_ratio_numerator == format->aspect_ratio_numerator &&
-      std_format->aspect_ratio_denominator == format->aspect_ratio_denominator) {
+      std_format->aspect_ratio_denominator ==
+      format->aspect_ratio_denominator) {
     metric++;
   } else {
     metric++;
     i = schro_video_format_get_std_aspect_ratio (format);
     metric += schro_pack_estimate_uint (i);
-    if (i==0) {
+    if (i == 0) {
       metric += schro_pack_estimate_uint (format->aspect_ratio_numerator);
       metric += schro_pack_estimate_uint (format->aspect_ratio_denominator);
     }
@@ -388,7 +392,7 @@ schro_video_format_get_video_format_metric (SchroVideoFormat *format, int i)
  * Returns: an index to the optimal standard format
  */
 SchroVideoFormatEnum
-schro_video_format_get_std_video_format (SchroVideoFormat *format)
+schro_video_format_get_std_video_format (SchroVideoFormat * format)
 {
   int metric;
   int max_index;
@@ -397,7 +401,7 @@ schro_video_format_get_std_video_format (SchroVideoFormat *format)
 
   max_index = 0;
   max_metric = schro_video_format_get_video_format_metric (format, 1);
-  for(i=1;i<ARRAY_SIZE (schro_video_formats); i++) {
+  for (i = 1; i < ARRAY_SIZE (schro_video_formats); i++) {
     metric = schro_video_format_get_video_format_metric (format, i);
     if (metric > max_metric) {
       max_index = i;
@@ -408,24 +412,24 @@ schro_video_format_get_std_video_format (SchroVideoFormat *format)
 }
 
 typedef struct _SchroFrameRate SchroFrameRate;
-struct _SchroFrameRate {
+struct _SchroFrameRate
+{
   int numerator;
   int denominator;
 };
 
-static SchroFrameRate
-schro_frame_rates[] = {
-  { 0, 0 },
-  { 24000, 1001 },
-  { 24, 1 },
-  { 25, 1 },
-  { 30000, 1001 },
-  { 30, 1 },
-  { 50, 1 },
-  { 60000, 1001 },
-  { 60, 1 },
-  { 15000, 1001 },
-  { 25, 2 }
+static SchroFrameRate schro_frame_rates[] = {
+  {0, 0},
+  {24000, 1001},
+  {24, 1},
+  {25, 1},
+  {30000, 1001},
+  {30, 1},
+  {50, 1},
+  {60000, 1001},
+  {60, 1},
+  {15000, 1001},
+  {25, 2}
 };
 
 /**
@@ -436,10 +440,11 @@ schro_frame_rates[] = {
  * Sets the frame rate of the video format structure pointed to by
  * @format to the Dirac standard frame specified by @index.
  */
-void schro_video_format_set_std_frame_rate (SchroVideoFormat *format, int index)
+void
+schro_video_format_set_std_frame_rate (SchroVideoFormat * format, int index)
 {
-  if (index < 1 || index >= ARRAY_SIZE(schro_frame_rates)) {
-    SCHRO_ERROR("illegal frame rate index");
+  if (index < 1 || index >= ARRAY_SIZE (schro_frame_rates)) {
+    SCHRO_ERROR ("illegal frame rate index");
     return;
   }
 
@@ -462,11 +467,12 @@ void schro_video_format_set_std_frame_rate (SchroVideoFormat *format, int index)
  * Returns: index to a standard Dirac frame rate, or 0 if the frame rate
  * is custom.
  */
-int schro_video_format_get_std_frame_rate (SchroVideoFormat *format)
+int
+schro_video_format_get_std_frame_rate (SchroVideoFormat * format)
 {
   int i;
 
-  for(i=1;i<ARRAY_SIZE(schro_frame_rates);i++){
+  for (i = 1; i < ARRAY_SIZE (schro_frame_rates); i++) {
     if (format->frame_rate_numerator == schro_frame_rates[i].numerator &&
         format->frame_rate_denominator == schro_frame_rates[i].denominator) {
       return i;
@@ -477,20 +483,20 @@ int schro_video_format_get_std_frame_rate (SchroVideoFormat *format)
 }
 
 typedef struct _SchroPixelAspectRatio SchroPixelAspectRatio;
-struct _SchroPixelAspectRatio {
+struct _SchroPixelAspectRatio
+{
   int numerator;
   int denominator;
 };
 
-static const SchroPixelAspectRatio
-schro_aspect_ratios[] = {
-  { 0, 0 },
-  { 1, 1 },
-  { 10, 11 },
-  { 12, 11 },
-  { 40, 33 },
-  { 16, 11 },
-  { 4, 3 }
+static const SchroPixelAspectRatio schro_aspect_ratios[] = {
+  {0, 0},
+  {1, 1},
+  {10, 11},
+  {12, 11},
+  {40, 33},
+  {16, 11},
+  {4, 3}
 };
 
 /*
@@ -501,10 +507,11 @@ schro_aspect_ratios[] = {
  * Sets the pixel aspect ratio of the video format structure pointed to
  * by @format to the standard pixel aspect ratio indicated by @index.
  */
-void schro_video_format_set_std_aspect_ratio (SchroVideoFormat *format, int index)
+void
+schro_video_format_set_std_aspect_ratio (SchroVideoFormat * format, int index)
 {
-  if (index < 1 || index >= ARRAY_SIZE(schro_aspect_ratios)) {
-    SCHRO_ERROR("illegal pixel aspect ratio index");
+  if (index < 1 || index >= ARRAY_SIZE (schro_aspect_ratios)) {
+    SCHRO_ERROR ("illegal pixel aspect ratio index");
     return;
   }
 
@@ -528,11 +535,12 @@ void schro_video_format_set_std_aspect_ratio (SchroVideoFormat *format, int inde
  * Returns: index to standard pixel aspect ratio, or 0 if there is no
  * corresponding standard pixel aspect ratio.
  */
-int schro_video_format_get_std_aspect_ratio (SchroVideoFormat *format)
+int
+schro_video_format_get_std_aspect_ratio (SchroVideoFormat * format)
 {
   int i;
 
-  for(i=1;i<ARRAY_SIZE(schro_aspect_ratios);i++){
+  for (i = 1; i < ARRAY_SIZE (schro_aspect_ratios); i++) {
     if (format->aspect_ratio_numerator ==
         schro_aspect_ratios[i].numerator &&
         format->aspect_ratio_denominator ==
@@ -545,7 +553,8 @@ int schro_video_format_get_std_aspect_ratio (SchroVideoFormat *format)
 }
 
 typedef struct _SchroSignalRangeStruct SchroSignalRangeStruct;
-struct _SchroSignalRangeStruct {
+struct _SchroSignalRangeStruct
+{
   int luma_offset;
   int luma_excursion;
   int chroma_offset;
@@ -553,11 +562,11 @@ struct _SchroSignalRangeStruct {
 };
 
 static const SchroSignalRangeStruct schro_signal_ranges[] = {
-  { 0, 0, 0, 0 },
-  { 0, 255, 128, 255 },
-  { 16, 219, 128, 224 },
-  { 64, 876, 512, 896 },
-  { 256, 3504, 2048, 3584 }
+  {0, 0, 0, 0},
+  {0, 255, 128, 255},
+  {16, 219, 128, 224},
+  {64, 876, 512, 896},
+  {256, 3504, 2048, 3584}
 };
 
 /**
@@ -568,11 +577,12 @@ static const SchroSignalRangeStruct schro_signal_ranges[] = {
  * Sets the signal range of the video format structure to one of the
  * standard values indicated by @index.
  */
-void schro_video_format_set_std_signal_range (SchroVideoFormat *format,
+void
+schro_video_format_set_std_signal_range (SchroVideoFormat * format,
     SchroSignalRange i)
 {
-  if (i < 1 || i >= ARRAY_SIZE(schro_signal_ranges)) {
-    SCHRO_ERROR("illegal signal range index");
+  if (i < 1 || i >= ARRAY_SIZE (schro_signal_ranges)) {
+    SCHRO_ERROR ("illegal signal range index");
     return;
   }
 
@@ -598,11 +608,11 @@ void schro_video_format_set_std_signal_range (SchroVideoFormat *format,
  * corresponding standard signal range.
  */
 SchroSignalRange
-schro_video_format_get_std_signal_range (SchroVideoFormat *format)
+schro_video_format_get_std_signal_range (SchroVideoFormat * format)
 {
   int i;
 
-  for(i=1;i<ARRAY_SIZE(schro_signal_ranges);i++){
+  for (i = 1; i < ARRAY_SIZE (schro_signal_ranges); i++) {
     if (format->luma_offset == schro_signal_ranges[i].luma_offset &&
         format->luma_excursion == schro_signal_ranges[i].luma_excursion &&
         format->chroma_offset == schro_signal_ranges[i].chroma_offset &&
@@ -616,38 +626,34 @@ schro_video_format_get_std_signal_range (SchroVideoFormat *format)
 }
 
 typedef struct _SchroColourSpecStruct SchroColourSpecStruct;
-struct _SchroColourSpecStruct {
+struct _SchroColourSpecStruct
+{
   int colour_primaries;
   int colour_matrix;
   int transfer_function;
 };
 
 static const SchroColourSpecStruct schro_colour_specs[] = {
-  { /* Custom */
-    SCHRO_COLOUR_PRIMARY_HDTV,
-    SCHRO_COLOUR_MATRIX_HDTV,
-    SCHRO_TRANSFER_CHAR_TV_GAMMA
-  },
-  { /* SDTV 525 */
-    SCHRO_COLOUR_PRIMARY_SDTV_525,
-    SCHRO_COLOUR_MATRIX_SDTV,
-    SCHRO_TRANSFER_CHAR_TV_GAMMA
-  },
-  { /* SDTV 625 */
-    SCHRO_COLOUR_PRIMARY_SDTV_625,
-    SCHRO_COLOUR_MATRIX_SDTV,
-    SCHRO_TRANSFER_CHAR_TV_GAMMA
-  },
-  { /* HDTV */
-    SCHRO_COLOUR_PRIMARY_HDTV,
-    SCHRO_COLOUR_MATRIX_HDTV,
-    SCHRO_TRANSFER_CHAR_TV_GAMMA
-  },
-  { /* Cinema */
-    SCHRO_COLOUR_PRIMARY_CINEMA,
-    SCHRO_COLOUR_MATRIX_HDTV,
-    SCHRO_TRANSFER_CHAR_TV_GAMMA
-  }
+  {                             /* Custom */
+        SCHRO_COLOUR_PRIMARY_HDTV,
+        SCHRO_COLOUR_MATRIX_HDTV,
+      SCHRO_TRANSFER_CHAR_TV_GAMMA},
+  {                             /* SDTV 525 */
+        SCHRO_COLOUR_PRIMARY_SDTV_525,
+        SCHRO_COLOUR_MATRIX_SDTV,
+      SCHRO_TRANSFER_CHAR_TV_GAMMA},
+  {                             /* SDTV 625 */
+        SCHRO_COLOUR_PRIMARY_SDTV_625,
+        SCHRO_COLOUR_MATRIX_SDTV,
+      SCHRO_TRANSFER_CHAR_TV_GAMMA},
+  {                             /* HDTV */
+        SCHRO_COLOUR_PRIMARY_HDTV,
+        SCHRO_COLOUR_MATRIX_HDTV,
+      SCHRO_TRANSFER_CHAR_TV_GAMMA},
+  {                             /* Cinema */
+        SCHRO_COLOUR_PRIMARY_CINEMA,
+        SCHRO_COLOUR_MATRIX_HDTV,
+      SCHRO_TRANSFER_CHAR_TV_GAMMA}
 };
 
 /**
@@ -658,11 +664,12 @@ static const SchroColourSpecStruct schro_colour_specs[] = {
  * Sets the colour specification of the video format structure to one of the
  * standard values indicated by @index.
  */
-void schro_video_format_set_std_colour_spec (SchroVideoFormat *format,
+void
+schro_video_format_set_std_colour_spec (SchroVideoFormat * format,
     SchroColourSpec i)
 {
-  if (i < 0 || i >= ARRAY_SIZE(schro_colour_specs)) {
-    SCHRO_ERROR("illegal signal range index");
+  if (i < 0 || i >= ARRAY_SIZE (schro_colour_specs)) {
+    SCHRO_ERROR ("illegal signal range index");
     return;
   }
 
@@ -687,11 +694,11 @@ void schro_video_format_set_std_colour_spec (SchroVideoFormat *format,
  * corresponding standard colour specification.
  */
 SchroColourSpec
-schro_video_format_get_std_colour_spec (SchroVideoFormat *format)
+schro_video_format_get_std_colour_spec (SchroVideoFormat * format)
 {
   int i;
 
-  for(i=1;i<ARRAY_SIZE(schro_colour_specs);i++){
+  for (i = 1; i < ARRAY_SIZE (schro_colour_specs); i++) {
     if (format->colour_primaries == schro_colour_specs[i].colour_primaries &&
         format->colour_matrix == schro_colour_specs[i].colour_matrix &&
         format->transfer_function == schro_colour_specs[i].transfer_function) {
@@ -711,53 +718,53 @@ schro_video_format_get_std_colour_spec (SchroVideoFormat *format)
  * field height, or half of the video height.
  */
 int
-schro_video_format_get_picture_height (SchroVideoFormat *format)
+schro_video_format_get_picture_height (SchroVideoFormat * format)
 {
   if (format->interlaced_coding) {
-    return ROUND_UP_SHIFT(format->height,1);
+    return ROUND_UP_SHIFT (format->height, 1);
   }
   return format->height;
 }
 
 #ifdef unused
 int
-schro_video_format_get_chroma_width (SchroVideoFormat *format)
+schro_video_format_get_chroma_width (SchroVideoFormat * format)
 {
-  return ROUND_UP_SHIFT(format->width,
-      SCHRO_CHROMA_FORMAT_H_SHIFT(format->chroma_format));
+  return ROUND_UP_SHIFT (format->width,
+      SCHRO_CHROMA_FORMAT_H_SHIFT (format->chroma_format));
 }
 #endif
 
 #ifdef unused
 int
-schro_video_format_get_chroma_height (SchroVideoFormat *format)
+schro_video_format_get_chroma_height (SchroVideoFormat * format)
 {
-  return ROUND_UP_SHIFT(format->height,
-      SCHRO_CHROMA_FORMAT_V_SHIFT(format->chroma_format));
+  return ROUND_UP_SHIFT (format->height,
+      SCHRO_CHROMA_FORMAT_V_SHIFT (format->chroma_format));
 }
 #endif
 
 void
-schro_video_format_get_picture_luma_size (SchroVideoFormat *format,
+schro_video_format_get_picture_luma_size (SchroVideoFormat * format,
     int *width, int *height)
 {
   *width = format->width;
-  *height = ROUND_UP_SHIFT(format->height, format->interlaced_coding);
+  *height = ROUND_UP_SHIFT (format->height, format->interlaced_coding);
 }
 
 void
-schro_video_format_get_picture_chroma_size (SchroVideoFormat *format,
+schro_video_format_get_picture_chroma_size (SchroVideoFormat * format,
     int *width, int *height)
 {
-  *width = ROUND_UP_SHIFT(format->width,
-      SCHRO_CHROMA_FORMAT_H_SHIFT(format->chroma_format));
-  *height = ROUND_UP_SHIFT(format->height,
-      SCHRO_CHROMA_FORMAT_V_SHIFT(format->chroma_format) +
+  *width = ROUND_UP_SHIFT (format->width,
+      SCHRO_CHROMA_FORMAT_H_SHIFT (format->chroma_format));
+  *height = ROUND_UP_SHIFT (format->height,
+      SCHRO_CHROMA_FORMAT_V_SHIFT (format->chroma_format) +
       format->interlaced_coding);
 }
 
 void
-schro_video_format_get_iwt_alloc_size (SchroVideoFormat *format,
+schro_video_format_get_iwt_alloc_size (SchroVideoFormat * format,
     int *width, int *height, int transform_depth)
 {
   int picture_chroma_width;
@@ -766,19 +773,18 @@ schro_video_format_get_iwt_alloc_size (SchroVideoFormat *format,
   schro_video_format_get_picture_chroma_size (format, &picture_chroma_width,
       &picture_chroma_height);
 
-  picture_chroma_width = ROUND_UP_POW2(picture_chroma_width,
-      transform_depth);
-  picture_chroma_height = ROUND_UP_POW2(picture_chroma_height,
+  picture_chroma_width = ROUND_UP_POW2 (picture_chroma_width, transform_depth);
+  picture_chroma_height = ROUND_UP_POW2 (picture_chroma_height,
       transform_depth);
 
   *width = picture_chroma_width <<
-    SCHRO_CHROMA_FORMAT_H_SHIFT(format->chroma_format);
+      SCHRO_CHROMA_FORMAT_H_SHIFT (format->chroma_format);
   *height = picture_chroma_height <<
-      SCHRO_CHROMA_FORMAT_V_SHIFT(format->chroma_format);
+      SCHRO_CHROMA_FORMAT_V_SHIFT (format->chroma_format);
 }
 
 schro_bool
-schro_video_format_check_MP_DL (SchroVideoFormat *format)
+schro_video_format_check_MP_DL (SchroVideoFormat * format)
 {
   SchroVideoFormat base_format;
 
@@ -788,8 +794,7 @@ schro_video_format_check_MP_DL (SchroVideoFormat *format)
 
   schro_video_format_set_std_video_format (&base_format, format->index);
 
-  if (format->width > base_format.width ||
-      format->height > base_format.height) {
+  if (format->width > base_format.width || format->height > base_format.height) {
     return FALSE;
   }
 
@@ -819,7 +824,7 @@ schro_video_format_check_MP_DL (SchroVideoFormat *format)
 }
 
 schro_bool
-schro_video_format_check_VC2_DL (SchroVideoFormat *format)
+schro_video_format_check_VC2_DL (SchroVideoFormat * format)
 {
   SchroVideoFormat base_format;
 
@@ -829,10 +834,9 @@ schro_video_format_check_VC2_DL (SchroVideoFormat *format)
 
   schro_video_format_set_std_video_format (&base_format, format->index);
 
-  if (memcmp (&base_format, format, sizeof(SchroVideoFormat)) != 0) {
+  if (memcmp (&base_format, format, sizeof (SchroVideoFormat)) != 0) {
     return FALSE;
   }
 
   return TRUE;
 }
-
