@@ -4,7 +4,11 @@
 
 #include <math.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <schroedinger/schroframe.h>
+#include <orc-test/orcrandom.h>
+
+extern OrcRandomContext context;
 
 double sgn(double x);
 double random_std (void);
@@ -28,5 +32,14 @@ void frame_dump (SchroFrame *test, SchroFrame *ref);
 
 int parse_packet (FILE *file, void **data, int *size);
 
+#define rand_u8() (rand()&0xff)
+#define rand_f64() (((rand()/(RAND_MAX+1.0))+rand())/(RAND_MAX+1.0))
+
+void interleave (int16_t *a, int n);
+void deinterleave (int16_t *a, int n);
+void extend(int16_t *a, int n);
+void synth(int16_t *a, int n, int filter);
+void split (int16_t *a, int n, int filter);
+
 #endif
 
