@@ -10,21 +10,21 @@
 #include <stdlib.h>
 #include <string.h>
 
-#define OIL_ENABLE_UNSTABLE_API
-#include <liboil/liboilprofile.h>
+#include <orc-test/orcprofile.h>
 
 int
 main (int argc, char *argv[])
 {
   SchroFrame *dest;
   SchroFrame *ref;
+  SchroFrame *addframe;
   SchroUpsampledFrame *uref;
   SchroParams params;
   SchroVideoFormat video_format;
   SchroMotionVector *motion_vectors;
   int i;
   int j;
-  OilProfile prof;
+  OrcProfile prof;
   double ave, std;
 
   schro_init();
@@ -55,6 +55,10 @@ main (int argc, char *argv[])
       video_format.width, video_format.height, 32);
   schro_frame_clear(ref);
 
+  addframe = schro_frame_new_and_alloc (NULL, SCHRO_FRAME_FORMAT_S16_420,
+      video_format.width, video_format.height);
+  schro_frame_clear(addframe);
+
   uref = schro_upsampled_frame_new (ref);
 
   schro_upsampled_frame_upsample (uref);
@@ -74,7 +78,7 @@ main (int argc, char *argv[])
   }
 
   for(i=0;i<10;i++){
-    oil_profile_init (&prof);
+    orc_profile_init (&prof);
     for(j=0;j<10;j++){
       SchroMotion *motion;
       void *mv_save;
@@ -82,13 +86,13 @@ main (int argc, char *argv[])
       motion = schro_motion_new (&params, uref, NULL);
       mv_save = motion->motion_vectors;
       motion->motion_vectors = motion_vectors;
-      oil_profile_start(&prof);
-      schro_motion_render (motion, dest);
-      oil_profile_stop(&prof);
+      orc_profile_start(&prof);
+      schro_motion_render (motion, dest, addframe, FALSE, NULL);
+      orc_profile_stop(&prof);
       motion->motion_vectors = mv_save;
       schro_motion_free (motion);
     }
-    oil_profile_get_ave_std (&prof, &ave, &std);
+    orc_profile_get_ave_std (&prof, &ave, &std);
     printf("cycles %g %g\n", ave, std);
   }
 
