@@ -11,8 +11,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#define OIL_ENABLE_UNSTABLE_API
-#include <liboil/liboilrandom.h>
+#include "common.h"
 
 void
 schro_frame_create_pattern (SchroFrame *frame, int type)
@@ -22,9 +21,9 @@ schro_frame_create_pattern (SchroFrame *frame, int type)
 
   switch (type) {
     case 0:
-      oil_random_u8 (frame->components[0].data, frame->components[0].length);
-      oil_random_u8 (frame->components[1].data, frame->components[1].length);
-      oil_random_u8 (frame->components[2].data, frame->components[2].length);
+      orc_random_bits (&context, frame->components[0].data, frame->components[0].length);
+      orc_random_bits (&context, frame->components[1].data, frame->components[1].length);
+      orc_random_bits (&context, frame->components[2].data, frame->components[2].length);
       break;
     case 1:
       for(k=0;k<3;k++){
@@ -86,6 +85,7 @@ main (int argc, char *argv[])
   SchroFrame *dest;
   SchroFrame *dest_u8;
   SchroFrame *ref;
+  SchroFrame *addframe;
   SchroUpsampledFrame *uref;
   SchroParams params;
   SchroVideoFormat video_format;
@@ -94,6 +94,9 @@ main (int argc, char *argv[])
 
   schro_init();
 
+  memset (&video_format, 0, sizeof(video_format));
+  memset (&params, 0, sizeof(params));
+
   video_format.width = 720;
   video_format.height = 480;
   video_format.chroma_format = SCHRO_CHROMA_420;
@@ -109,10 +112,12 @@ main (int argc, char *argv[])
 
   dest = schro_frame_new_and_alloc (NULL, SCHRO_FRAME_FORMAT_S16_420,
       video_format.width, video_format.height);
-  ref = schro_frame_new_and_alloc (NULL, SCHRO_FRAME_FORMAT_U8_420,
-      video_format.width, video_format.height);
+  ref = schro_frame_new_and_alloc_extended (NULL, SCHRO_FRAME_FORMAT_U8_420,
+      video_format.width, video_format.height, 32);
   dest_u8 = schro_frame_new_and_alloc (NULL, SCHRO_FRAME_FORMAT_U8_420,
       video_format.width, video_format.height);
+  addframe = schro_frame_new_and_alloc (NULL, SCHRO_FRAME_FORMAT_S16_420,
+      video_format.width, video_format.height);
 
   schro_frame_clear(dest);
   schro_frame_create_pattern(ref,1);
@@ -157,7 +162,7 @@ main (int argc, char *argv[])
     motion.src2 = NULL;
     motion.motion_vectors = motion_vectors;
     motion.params = &params;
-    schro_motion_render (&motion, dest);
+    schro_motion_render (&motion, dest, addframe, FALSE, NULL);
   }
 
   schro_frame_convert (dest_u8, dest);
