@@ -5,8 +5,6 @@
 
 #include <schroedinger/schro.h>
 #include <schroedinger/schrowavelet.h>
-#include <schroedinger/schrooil.h>
-#include <liboil/liboil.h>
 
 #include <stdio.h>
 #include <string.h>
@@ -35,20 +33,39 @@ main (int argc, char *argv[])
       printf("filter %d n_levels %d\n", filter, j+1);
       n = 3*(j+1)+1;
 
-      min = encoder->subband_weights[filter][j][0];
+      min = encoder->intra_subband_weights[filter][j][0];
       for(i=0;i<n;i++){
-        if (encoder->subband_weights[filter][j][i] < min) {
-          min = encoder->subband_weights[filter][j][i];
+        if (encoder->intra_subband_weights[filter][j][i] < min) {
+          min = encoder->intra_subband_weights[filter][j][i];
         }
       }
       for(i=0;i<n;i++){
-        x = encoder->subband_weights[filter][j][i]/min;
-        printf("%2d %6.3f %6.3f %d\n", i, encoder->subband_weights[filter][j][i],
+        x = encoder->intra_subband_weights[filter][j][i]/min;
+        printf("%2d %6.3f %6.3f %d\n", i, encoder->intra_subband_weights[filter][j][i],
+            x, gain_to_quant_index(x));
+      }
+    }
+  }
+  for(filter=0;filter<8;filter++){
+    for(j=0;j<4;j++){
+      printf("filter %d n_levels %d\n", filter, j+1);
+      n = 3*(j+1)+1;
+
+      min = encoder->inter_subband_weights[filter][j][0];
+      for(i=0;i<n;i++){
+        if (encoder->inter_subband_weights[filter][j][i] < min) {
+          min = encoder->inter_subband_weights[filter][j][i];
+        }
+      }
+      for(i=0;i<n;i++){
+        x = encoder->inter_subband_weights[filter][j][i]/min;
+        printf("%2d %6.3f %6.3f %d\n", i, encoder->inter_subband_weights[filter][j][i],
             x, gain_to_quant_index(x));
       }
     }
   }
 
+
   return 0;
 }
 
